@@ -23,6 +23,8 @@ import java.util.Arrays;
 import org.apache.commons.math.Field;
 import org.apache.commons.math.FieldElement;
 import org.apache.commons.math.MathRuntimeException;
+import org.apache.commons.math.linear.MatrixVisitorException;
+import org.apache.commons.math.exception.util.LocalizedFormats;
 
 /**
  * Basic implementation of {@link FieldMatrix} methods regardless of the underlying storage.
@@ -30,7 +32,7 @@ import org.apache.commons.math.MathRuntimeException;
  * matrix elements. Derived class can provide faster implementations. </p>
  *
  * @param <T> the type of the field elements
- * @version $Revision: 903046 $ $Date: 2010-01-25 21:07:26 -0500 (Mon, 25 Jan 2010) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  * @since 2.0
  */
 public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements FieldMatrix<T> {
@@ -64,15 +66,13 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
     protected AbstractFieldMatrix(final Field<T> field,
                                   final int rowDimension, final int columnDimension)
         throws IllegalArgumentException {
-        if (rowDimension <= 0 ) {
+        if (rowDimension < 1 ) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "invalid row dimension {0} (must be positive)",
-                    rowDimension);
+                    LocalizedFormats.INSUFFICIENT_DIMENSION, rowDimension, 1);
         }
-        if (columnDimension <= 0) {
+        if (columnDimension < 1) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "invalid column dimension {0} (must be positive)",
-                    columnDimension);
+                    LocalizedFormats.INSUFFICIENT_DIMENSION, columnDimension, 1);
         }
         this.field = field;
     }
@@ -87,10 +87,10 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
     protected static <T extends FieldElement<T>> Field<T> extractField(final T[][] d)
         throws IllegalArgumentException {
         if (d.length == 0) {
-            throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one row");
+            throw MathRuntimeException.createIllegalArgumentException(LocalizedFormats.AT_LEAST_ONE_ROW);
         }
         if (d[0].length == 0) {
-            throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one column");
+            throw MathRuntimeException.createIllegalArgumentException(LocalizedFormats.AT_LEAST_ONE_COLUMN);
         }
         return d[0][0].getField();
     }
@@ -105,7 +105,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
     protected static <T extends FieldElement<T>> Field<T> extractField(final T[] d)
         throws IllegalArgumentException {
         if (d.length == 0) {
-            throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one row");
+            throw MathRuntimeException.createIllegalArgumentException(LocalizedFormats.AT_LEAST_ONE_ROW);
         }
         return d[0].getField();
     }
@@ -338,7 +338,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         final int columnsCount = endColumn + 1 - startColumn;
         if ((destination.length < rowsCount) || (destination[0].length < columnsCount)) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     destination.length, destination[0].length,
                     rowsCount, columnsCount);
         }
@@ -380,7 +380,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         if ((destination.length < selectedRows.length) ||
             (destination[0].length < selectedColumns.length)) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     destination.length, destination[0].length,
                     selectedRows.length, selectedColumns.length);
         }
@@ -401,18 +401,18 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
 
         final int nRows = subMatrix.length;
         if (nRows == 0) {
-            throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one row");
+            throw MathRuntimeException.createIllegalArgumentException(LocalizedFormats.AT_LEAST_ONE_ROW);
         }
 
         final int nCols = subMatrix[0].length;
         if (nCols == 0) {
-            throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one column");
+            throw MathRuntimeException.createIllegalArgumentException(LocalizedFormats.AT_LEAST_ONE_COLUMN);
         }
 
         for (int r = 1; r < nRows; ++r) {
             if (subMatrix[r].length != nCols) {
                 throw MathRuntimeException.createIllegalArgumentException(
-                        "some rows have length {0} while others have length {1}",
+                        LocalizedFormats.DIFFERENT_ROWS_LENGTHS,
                         nCols, subMatrix[r].length);
             }
         }
@@ -454,7 +454,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         if ((matrix.getRowDimension() != 1) ||
             (matrix.getColumnDimension() != nCols)) {
             throw new InvalidMatrixException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     matrix.getRowDimension(), matrix.getColumnDimension(), 1, nCols);
         }
         for (int i = 0; i < nCols; ++i) {
@@ -487,7 +487,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         if ((matrix.getRowDimension() != nRows) ||
             (matrix.getColumnDimension() != 1)) {
             throw new InvalidMatrixException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     matrix.getRowDimension(), matrix.getColumnDimension(), nRows, 1);
         }
         for (int i = 0; i < nRows; ++i) {
@@ -510,7 +510,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         final int nCols = getColumnDimension();
         if (vector.getDimension() != nCols) {
             throw new InvalidMatrixException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     1, vector.getDimension(), 1, nCols);
         }
         for (int i = 0; i < nCols; ++i) {
@@ -533,7 +533,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         final int nRows = getRowDimension();
         if (vector.getDimension() != nRows) {
             throw new InvalidMatrixException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     vector.getDimension(), 1, nRows, 1);
         }
         for (int i = 0; i < nRows; ++i) {
@@ -565,7 +565,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         final int nCols = getColumnDimension();
         if (array.length != nCols) {
             throw new InvalidMatrixException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     1, array.length, 1, nCols);
         }
         for (int i = 0; i < nCols; ++i) {
@@ -597,7 +597,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         final int nRows = getRowDimension();
         if (array.length != nRows) {
             throw new InvalidMatrixException(
-                    "dimensions mismatch: got {0}x{1} but expected {2}x{3}",
+                    LocalizedFormats.DIMENSIONS_MISMATCH_2x2,
                     array.length, 1, nRows, 1);
         }
         for (int i = 0; i < nRows; ++i) {
@@ -676,7 +676,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         final int nCols = getColumnDimension();
         if (v.length != nCols) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "vector length mismatch: got {0} but expected {1}",
+                    LocalizedFormats.VECTOR_LENGTH_MISMATCH,
                     v.length, nCols);
         }
 
@@ -703,7 +703,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
             final int nCols = getColumnDimension();
             if (v.getDimension() != nCols) {
                 throw MathRuntimeException.createIllegalArgumentException(
-                        "vector length mismatch: got {0} but expected {1}",
+                        LocalizedFormats.VECTOR_LENGTH_MISMATCH,
                         v.getDimension(), nCols);
             }
 
@@ -728,7 +728,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         final int nCols = getColumnDimension();
         if (v.length != nRows) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "vector length mismatch: got {0} but expected {1}",
+                    LocalizedFormats.VECTOR_LENGTH_MISMATCH,
                     v.length, nRows);
         }
 
@@ -756,7 +756,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
             final int nCols = getColumnDimension();
             if (v.getDimension() != nRows) {
                 throw MathRuntimeException.createIllegalArgumentException(
-                        "vector length mismatch: got {0} but expected {1}",
+                        LocalizedFormats.VECTOR_LENGTH_MISMATCH,
                         v.getDimension(), nRows);
             }
 
@@ -938,7 +938,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
     public String toString() {
         final int nRows = getRowDimension();
         final int nCols = getColumnDimension();
-        final StringBuffer res = new StringBuffer();
+        final StringBuilder res = new StringBuilder();
         String fullClassName = getClass().getName();
         String shortClassName = fullClassName.substring(fullClassName.lastIndexOf('.') + 1);
         res.append(shortClassName).append("{");
@@ -1021,7 +1021,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
      */
     protected void checkRowIndex(final int row) {
         if (row < 0 || row >= getRowDimension()) {
-            throw new MatrixIndexException("row index {0} out of allowed range [{1}, {2}]",
+            throw new MatrixIndexException(LocalizedFormats.ROW_INDEX_OUT_OF_RANGE,
                                            row, 0, getRowDimension() - 1);
         }
     }
@@ -1034,7 +1034,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
     protected void checkColumnIndex(final int column)
         throws MatrixIndexException {
         if (column < 0 || column >= getColumnDimension()) {
-            throw new MatrixIndexException("column index {0} out of allowed range [{1}, {2}]",
+            throw new MatrixIndexException(LocalizedFormats.COLUMN_INDEX_OUT_OF_RANGE,
                                            column, 0, getColumnDimension() - 1);
         }
     }
@@ -1054,14 +1054,14 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         checkRowIndex(startRow);
         checkRowIndex(endRow);
         if (startRow > endRow) {
-            throw new MatrixIndexException("initial row {0} after final row {1}",
+            throw new MatrixIndexException(LocalizedFormats.INITIAL_ROW_AFTER_FINAL_ROW,
                                            startRow, endRow);
         }
 
         checkColumnIndex(startColumn);
         checkColumnIndex(endColumn);
         if (startColumn > endColumn) {
-            throw new MatrixIndexException("initial column {0} after final column {1}",
+            throw new MatrixIndexException(LocalizedFormats.INITIAL_COLUMN_AFTER_FINAL_COLUMN,
                                            startColumn, endColumn);
         }
 
@@ -1079,9 +1079,9 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
     protected void checkSubMatrixIndex(final int[] selectedRows, final int[] selectedColumns) {
         if (selectedRows.length * selectedColumns.length == 0) {
             if (selectedRows.length == 0) {
-                throw new MatrixIndexException("empty selected row index array");
+                throw new MatrixIndexException(LocalizedFormats.EMPTY_SELECTED_ROW_INDEX_ARRAY);
             }
-            throw new MatrixIndexException("empty selected column index array");
+            throw new MatrixIndexException(LocalizedFormats.EMPTY_SELECTED_COLUMN_INDEX_ARRAY);
         }
 
         for (final int row : selectedRows) {
@@ -1101,7 +1101,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         if ((getRowDimension()    != m.getRowDimension()) ||
             (getColumnDimension() != m.getColumnDimension())) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "{0}x{1} and {2}x{3} matrices are not addition compatible",
+                    LocalizedFormats.NOT_ADDITION_COMPATIBLE_MATRICES,
                     getRowDimension(), getColumnDimension(),
                     m.getRowDimension(), m.getColumnDimension());
         }
@@ -1116,7 +1116,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
         if ((getRowDimension()    != m.getRowDimension()) ||
             (getColumnDimension() != m.getColumnDimension())) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "{0}x{1} and {2}x{3} matrices are not subtraction compatible",
+                    LocalizedFormats.NOT_SUBTRACTION_COMPATIBLE_MATRICES,
                     getRowDimension(), getColumnDimension(),
                     m.getRowDimension(), m.getColumnDimension());
         }
@@ -1130,7 +1130,7 @@ public abstract class AbstractFieldMatrix<T extends FieldElement<T>> implements
     protected void checkMultiplicationCompatible(final FieldMatrix<T> m) {
         if (getColumnDimension() != m.getRowDimension()) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "{0}x{1} and {2}x{3} matrices are not multiplication compatible",
+                    LocalizedFormats.NOT_MULTIPLICATION_COMPATIBLE_MATRICES,
                     getRowDimension(), getColumnDimension(),
                     m.getRowDimension(), m.getColumnDimension());
         }
