@@ -20,6 +20,8 @@ package org.apache.commons.math.linear;
 import java.io.Serializable;
 
 import org.apache.commons.math.MathRuntimeException;
+import org.apache.commons.math.linear.MatrixVisitorException;
+import org.apache.commons.math.exception.util.LocalizedFormats;
 
 /**
  * Implementation of RealMatrix using a double[][] array to store entries and
@@ -35,10 +37,10 @@ import org.apache.commons.math.MathRuntimeException;
  * <p>
  * <strong>Usage notes</strong>:<br>
  * <ul><li>
- * The LU decomposition is cached and reused on subsequent calls.   
+ * The LU decomposition is cached and reused on subsequent calls.
  * If data are modified via references to the underlying array obtained using
  * <code>getDataRef()</code>, then the stored LU decomposition will not be
- * discarded.  In this case, you need to explicitly invoke 
+ * discarded.  In this case, you need to explicitly invoke
  * <code>LUDecompose()</code> to recompute the decomposition
  * before using any of the methods above.</li>
  * <li>
@@ -47,10 +49,10 @@ import org.apache.commons.math.MathRuntimeException;
  * returns the element in the first row, first column of the matrix.</li></ul>
  * </p>
  *
- * @version $Revision: 783702 $ $Date: 2009-06-11 04:54:02 -0400 (Thu, 11 Jun 2009) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  */
 public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializable {
-    
+
     /** Serializable version identifier */
     private static final long serialVersionUID = -1067294169172445528L;
 
@@ -117,22 +119,23 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
         } else {
             if (d == null) {
                 throw new NullPointerException();
-            }   
+            }
             final int nRows = d.length;
             if (nRows == 0) {
-                throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one row"); 
+                throw MathRuntimeException.createIllegalArgumentException(
+                      LocalizedFormats.AT_LEAST_ONE_ROW);
             }
             final int nCols = d[0].length;
             if (nCols == 0) {
-                throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one column"); 
+                throw MathRuntimeException.createIllegalArgumentException(
+                      LocalizedFormats.AT_LEAST_ONE_COLUMN);
             }
             for (int r = 1; r < nRows; r++) {
                 if (d[r].length != nCols) {
                     throw MathRuntimeException.createIllegalArgumentException(
-                            "some rows have length {0} while others have length {1}",
-                            nCols, d[r].length);
+                          LocalizedFormats.DIFFERENT_ROWS_LENGTHS, nCols, d[r].length);
                 }
-            }       
+            }
             data = d;
         }
     }
@@ -309,34 +312,33 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
 
     /** {@inheritDoc} */
     @Override
-    public void setSubMatrix(final double[][] subMatrix, final int row, final int column) 
+    public void setSubMatrix(final double[][] subMatrix, final int row, final int column)
     throws MatrixIndexException {
         if (data == null) {
             if (row > 0) {
                 throw MathRuntimeException.createIllegalStateException(
-                        "first {0} rows are not initialized yet",
-                        row);
+                      LocalizedFormats.FIRST_ROWS_NOT_INITIALIZED_YET, row);
             }
             if (column > 0) {
                 throw MathRuntimeException.createIllegalStateException(
-                        "first {0} columns are not initialized yet",
-                        column);
+                      LocalizedFormats.FIRST_COLUMNS_NOT_INITIALIZED_YET, column);
             }
             final int nRows = subMatrix.length;
             if (nRows == 0) {
-                throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one row"); 
+                throw MathRuntimeException.createIllegalArgumentException(
+                      LocalizedFormats.AT_LEAST_ONE_ROW);
             }
 
             final int nCols = subMatrix[0].length;
             if (nCols == 0) {
-                throw MathRuntimeException.createIllegalArgumentException("matrix must have at least one column"); 
+                throw MathRuntimeException.createIllegalArgumentException(
+                      LocalizedFormats.AT_LEAST_ONE_COLUMN);
             }
             data = new double[subMatrix.length][nCols];
             for (int i = 0; i < data.length; ++i) {
                 if (subMatrix[i].length != nCols) {
                     throw MathRuntimeException.createIllegalArgumentException(
-                            "some rows have length {0} while others have length {1}",
-                            nCols, subMatrix[i].length); 
+                          LocalizedFormats.DIFFERENT_ROWS_LENGTHS, nCols, subMatrix[i].length);
                 }
                 System.arraycopy(subMatrix[i], 0, data[i + row], column, nCols);
             }
@@ -354,8 +356,7 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
             return data[row][column];
         } catch (ArrayIndexOutOfBoundsException e) {
             throw new MatrixIndexException(
-                    "no entry at indices ({0}, {1}) in a {2}x{3} matrix",
-                    row, column, getRowDimension(), getColumnDimension());
+                      LocalizedFormats.NO_SUCH_MATRIX_ENTRY, row, column, getRowDimension(), getColumnDimension());
         }
     }
 
@@ -367,8 +368,7 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
             data[row][column] = value;
         } catch (ArrayIndexOutOfBoundsException e) {
             throw new MatrixIndexException(
-                    "no entry at indices ({0}, {1}) in a {2}x{3} matrix",
-                    row, column, getRowDimension(), getColumnDimension());
+                      LocalizedFormats.NO_SUCH_MATRIX_ENTRY, row, column, getRowDimension(), getColumnDimension());
         }
     }
 
@@ -380,9 +380,8 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
             data[row][column] += increment;
         } catch (ArrayIndexOutOfBoundsException e) {
             throw new MatrixIndexException(
-                    "no entry at indices ({0}, {1}) in a {2}x{3} matrix",
-                    row, column, getRowDimension(), getColumnDimension());
-        }      
+                      LocalizedFormats.NO_SUCH_MATRIX_ENTRY, row, column, getRowDimension(), getColumnDimension());
+        }
     }
 
     /** {@inheritDoc} */
@@ -393,9 +392,8 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
             data[row][column] *= factor;
         } catch (ArrayIndexOutOfBoundsException e) {
             throw new MatrixIndexException(
-                    "no entry at indices ({0}, {1}) in a {2}x{3} matrix",
-                    row, column, getRowDimension(), getColumnDimension());
-        }      
+                      LocalizedFormats.NO_SUCH_MATRIX_ENTRY, row, column, getRowDimension(), getColumnDimension());
+        }
     }
 
     /** {@inheritDoc} */
@@ -418,8 +416,7 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
         final int nCols = this.getColumnDimension();
         if (v.length != nCols) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "vector length mismatch: got {0} but expected {1}",
-                    v.length, nCols);
+                  LocalizedFormats.VECTOR_LENGTH_MISMATCH, v.length, nCols);
         }
         final double[] out = new double[nRows];
         for (int row = 0; row < nRows; row++) {
@@ -442,8 +439,7 @@ public class Array2DRowRealMatrix extends AbstractRealMatrix implements Serializ
         final int nCols = getColumnDimension();
         if (v.length != nRows) {
             throw MathRuntimeException.createIllegalArgumentException(
-                    "vector length mismatch: got {0} but expected {1}",
-                    v.length, nRows);
+                  LocalizedFormats.VECTOR_LENGTH_MISMATCH, v.length, nRows);
         }
 
         final double[] out = new double[nCols];
