@@ -21,7 +21,6 @@ import java.io.IOException;
 import java.io.ObjectInput;
 import java.io.ObjectOutput;
 
-import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.ode.AbstractIntegrator;
 import org.apache.commons.math.ode.DerivativeException;
 import org.apache.commons.math.ode.sampling.StepInterpolator;
@@ -32,7 +31,7 @@ import org.apache.commons.math.ode.sampling.StepInterpolator;
  *
  * @see DormandPrince853Integrator
  *
- * @version $Revision: 811827 $ $Date: 2009-09-06 11:32:50 -0400 (Sun, 06 Sep 2009) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  * @since 1.2
  */
 
@@ -396,6 +395,7 @@ class DormandPrince853StepInterpolator
 
     double s;
     final double[] yTmp = new double[currentState.length];
+    final double pT = getGlobalPreviousTime();
 
     // k14
     for (int j = 0; j < currentState.length; ++j) {
@@ -404,7 +404,7 @@ class DormandPrince853StepInterpolator
           K14_11 * yDotK[10][j] + K14_12 * yDotK[11][j] + K14_13 * yDotK[12][j];
       yTmp[j] = currentState[j] + h * s;
     }
-    integrator.computeDerivatives(previousTime + C14 * h, yTmp, yDotKLast[0]);
+    integrator.computeDerivatives(pT + C14 * h, yTmp, yDotKLast[0]);
 
     // k15
     for (int j = 0; j < currentState.length; ++j) {
@@ -414,7 +414,7 @@ class DormandPrince853StepInterpolator
          K15_14 * yDotKLast[0][j];
      yTmp[j] = currentState[j] + h * s;
     }
-    integrator.computeDerivatives(previousTime + C15 * h, yTmp, yDotKLast[1]);
+    integrator.computeDerivatives(pT + C15 * h, yTmp, yDotKLast[1]);
 
     // k16
     for (int j = 0; j < currentState.length; ++j) {
@@ -424,7 +424,7 @@ class DormandPrince853StepInterpolator
           K16_14 * yDotKLast[0][j] +  K16_15 * yDotKLast[1][j];
       yTmp[j] = currentState[j] + h * s;
     }
-    integrator.computeDerivatives(previousTime + C16 * h, yTmp, yDotKLast[2]);
+    integrator.computeDerivatives(pT + C16 * h, yTmp, yDotKLast[2]);
 
   }
 
@@ -437,7 +437,9 @@ class DormandPrince853StepInterpolator
       // save the local attributes
       finalizeStep();
     } catch (DerivativeException e) {
-      throw MathRuntimeException.createIOException(e);
+        IOException ioe = new IOException(e.getLocalizedMessage());
+        ioe.initCause(e);
+        throw ioe;
     }
     final int dimension = (currentState == null) ? -1 : currentState.length;
     out.writeInt(dimension);
