@@ -23,6 +23,7 @@ import java.util.Comparator;
 import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.analysis.MultivariateRealFunction;
+import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.random.RandomVectorGenerator;
 
 /**
@@ -33,7 +34,7 @@ import org.apache.commons.math.random.RandomVectorGenerator;
  * turn with different starting points in order to avoid being trapped
  * into a local extremum when looking for a global one.
  * </p>
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  * @since 2.0
  */
 public class MultiStartMultivariateRealOptimizer
@@ -112,7 +113,7 @@ public class MultiStartMultivariateRealOptimizer
      */
     public RealPointValuePair[] getOptima() throws IllegalStateException {
         if (optima == null) {
-            throw MathRuntimeException.createIllegalStateException("no optimum computed yet");
+            throw MathRuntimeException.createIllegalStateException(LocalizedFormats.NO_OPTIMUM_COMPUTED_YET);
         }
         return optima.clone();
     }
@@ -161,7 +162,7 @@ public class MultiStartMultivariateRealOptimizer
     public RealPointValuePair optimize(final MultivariateRealFunction f,
                                          final GoalType goalType,
                                          double[] startPoint)
-        throws FunctionEvaluationException, OptimizationException {
+        throws FunctionEvaluationException, OptimizationException, FunctionEvaluationException {
 
         optima           = new RealPointValuePair[starts];
         totalIterations  = 0;
@@ -203,7 +204,7 @@ public class MultiStartMultivariateRealOptimizer
 
         if (optima[0] == null) {
             throw new OptimizationException(
-                    "none of the {0} start points lead to convergence",
+                    LocalizedFormats.NO_CONVERGENCE_WITH_ANY_START_POINT,
                     starts);
         }
 
