@@ -17,12 +17,13 @@
 
 package org.apache.commons.math.optimization.linear;
 
+import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.optimization.OptimizationException;
 
 /**
  * This class represents exceptions thrown by optimizers when no solution
  * fulfills the constraints.
- * @version $Revision: 758920 $ $Date: 2009-03-26 19:25:30 -0400 (Thu, 26 Mar 2009) $
+ * @version $Revision: 983921 $ $Date: 2010-08-10 12:46:06 +0200 (mar. 10 août 2010) $
  * @since 2.0
  */
 public class NoFeasibleSolutionException extends OptimizationException {
@@ -30,11 +31,11 @@ public class NoFeasibleSolutionException extends OptimizationException {
     /** Serializable version identifier. */
     private static final long serialVersionUID = -3044253632189082760L;
 
-    /** 
+    /**
      * Simple constructor using a default message.
      */
     public NoFeasibleSolutionException() {
-        super("no feasible solution");
+        super(LocalizedFormats.NO_FEASIBLE_SOLUTION);
     }
 
 }
