@@ -18,6 +18,7 @@
 package org.apache.commons.math.stat.correlation;
 
 import org.apache.commons.math.MathRuntimeException;
+import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.linear.BlockRealMatrix;
 import org.apache.commons.math.linear.RealMatrix;
 import org.apache.commons.math.stat.ranking.NaturalRanking;
@@ -33,7 +34,7 @@ import org.apache.commons.math.stat.ranking.RankingAlgorithm;
  * The ranking algorithm can be set using a constructor argument.</p>
  *
  * @since 2.0
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 983921 $ $Date: 2010-08-10 12:46:06 +0200 (mar. 10 août 2010) $
  */
 
 public class SpearmansCorrelation {
@@ -145,15 +146,16 @@ public class SpearmansCorrelation {
      */
     public double correlation(final double[] xArray, final double[] yArray)
     throws IllegalArgumentException {
-        if (xArray.length == yArray.length && xArray.length > 1) {
+        if (xArray.length != yArray.length) {
+            throw MathRuntimeException.createIllegalArgumentException(
+                  LocalizedFormats.DIMENSIONS_MISMATCH_SIMPLE, xArray.length, yArray.length);
+        } else if (xArray.length < 2) {
+            throw MathRuntimeException.createIllegalArgumentException(
+                  LocalizedFormats.INSUFFICIENT_DIMENSION, xArray.length, 2);
+        } else {
             return new PearsonsCorrelation().correlation(rankingAlgorithm.rank(xArray),
                     rankingAlgorithm.rank(yArray));
         }
-        else {
-            throw MathRuntimeException.createIllegalArgumentException(
-                    "invalid array dimensions. xArray has size {0}; yArray has {1} elements",
-                    xArray.length, yArray.length);
-        }
     }
 
     /**
