@@ -20,24 +20,25 @@ import org.apache.commons.math.MathException;
 import org.apache.commons.math.MathRuntimeException;
 import org.apache.commons.math.distribution.TDistribution;
 import org.apache.commons.math.distribution.TDistributionImpl;
+import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.stat.StatUtils;
 import org.apache.commons.math.stat.descriptive.StatisticalSummary;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Implements t-test statistics defined in the {@link TTest} interface.
  * <p>
- * Uses commons-math {@link org.apache.commons.math.distribution.TDistribution}
+ * Uses commons-math {@link org.apache.commons.math.distribution.TDistributionImpl}
  * implementation to estimate exact p-values.</p>
  *
- * @version $Revision: 885278 $ $Date: 2009-11-29 16:47:51 -0500 (Sun, 29 Nov 2009) $
+ * @version $Revision: 1042336 $ $Date: 2010-12-05 13:40:48 +0100 (dim. 05 déc. 2010) $
  */
 public class TTestImpl implements TTest  {
 
-    /** Message for insufficient data. */
-    private static final String INSUFFICIENT_DATA_MESSAGE =
-        "insufficient data for t statistic, needs at least 2, got {0}";
-
-    /** Distribution used to compute inference statistics. */
+    /** Distribution used to compute inference statistics.
+     * @deprecated in 2.2 (to be removed in 3.0).
+     */
+    @Deprecated
     private TDistribution distribution;
 
     /**
@@ -52,7 +53,9 @@ public class TTestImpl implements TTest  {
      * inference statistics.
      * @param t distribution used to compute inference statistics.
      * @since 1.2
+     * @deprecated in 2.2 (to be removed in 3.0).
      */
+    @Deprecated
     public TTestImpl(TDistribution t) {
         super();
         setDistribution(t);
@@ -908,7 +911,7 @@ public class TTestImpl implements TTest  {
      * @return t test statistic
      */
     protected double t(double m, double mu, double v, double n) {
-        return (m - mu) / Math.sqrt(v / n);
+        return (m - mu) / FastMath.sqrt(v / n);
     }
 
     /**
@@ -926,7 +929,7 @@ public class TTestImpl implements TTest  {
      */
     protected double t(double m1, double m2,  double v1, double v2, double n1,
             double n2)  {
-            return (m1 - m2) / Math.sqrt((v1 / n1) + (v2 / n2));
+            return (m1 - m2) / FastMath.sqrt((v1 / n1) + (v2 / n2));
     }
 
     /**
@@ -944,7 +947,7 @@ public class TTestImpl implements TTest  {
     protected double homoscedasticT(double m1, double m2,  double v1,
             double v2, double n1, double n2)  {
             double pooledVariance = ((n1  - 1) * v1 + (n2 -1) * v2 ) / (n1 + n2 - 2);
-            return (m1 - m2) / Math.sqrt(pooledVariance * (1d / n1 + 1d / n2));
+            return (m1 - m2) / FastMath.sqrt(pooledVariance * (1d / n1 + 1d / n2));
     }
 
     /**
@@ -959,7 +962,7 @@ public class TTestImpl implements TTest  {
      */
     protected double tTest(double m, double mu, double v, double n)
     throws MathException {
-        double t = Math.abs(t(m, mu, v, n));
+        double t = FastMath.abs(t(m, mu, v, n));
         distribution.setDegreesOfFreedom(n - 1);
         return 2.0 * distribution.cumulativeProbability(-t);
     }
@@ -982,7 +985,7 @@ public class TTestImpl implements TTest  {
     protected double tTest(double m1, double m2, double v1, double v2,
             double n1, double n2)
     throws MathException {
-        double t = Math.abs(t(m1, m2, v1, v2, n1, n2));
+        double t = FastMath.abs(t(m1, m2, v1, v2, n1, n2));
         double degreesOfFreedom = 0;
         degreesOfFreedom = df(v1, v2, n1, n2);
         distribution.setDegreesOfFreedom(degreesOfFreedom);
@@ -1007,7 +1010,7 @@ public class TTestImpl implements TTest  {
     protected double homoscedasticTTest(double m1, double m2, double v1,
             double v2, double n1, double n2)
     throws MathException {
-        double t = Math.abs(homoscedasticT(m1, m2, v1, v2, n1, n2));
+        double t = FastMath.abs(homoscedasticT(m1, m2, v1, v2, n1, n2));
         double degreesOfFreedom = n1 + n2 - 2;
         distribution.setDegreesOfFreedom(degreesOfFreedom);
         return 2.0 * distribution.cumulativeProbability(-t);
@@ -1017,7 +1020,9 @@ public class TTestImpl implements TTest  {
      * Modify the distribution used to compute inference statistics.
      * @param value the new distribution
      * @since 1.2
+     * @deprecated in 2.2 (to be removed in 3.0).
      */
+    @Deprecated
     public void setDistribution(TDistribution value) {
         distribution = value;
     }
@@ -1030,7 +1035,7 @@ public class TTestImpl implements TTest  {
         throws IllegalArgumentException {
         if ((alpha <= 0) || (alpha > 0.5)) {
             throw MathRuntimeException.createIllegalArgumentException(
-                  "out of bounds significance level {0}, must be between {1} and {2}",
+                  LocalizedFormats.OUT_OF_BOUND_SIGNIFICANCE_LEVEL,
                   alpha, 0.0, 0.5);
         }
     }
@@ -1043,7 +1048,7 @@ public class TTestImpl implements TTest  {
         throws IllegalArgumentException {
         if ((data == null) || (data.length < 2)) {
             throw MathRuntimeException.createIllegalArgumentException(
-                  INSUFFICIENT_DATA_MESSAGE,
+                  LocalizedFormats.INSUFFICIENT_DATA_FOR_T_STATISTIC,
                   (data == null) ? 0 : data.length);
         }
     }
@@ -1056,7 +1061,7 @@ public class TTestImpl implements TTest  {
         throws IllegalArgumentException {
         if ((stat == null) || (stat.getN() < 2)) {
             throw MathRuntimeException.createIllegalArgumentException(
-                  INSUFFICIENT_DATA_MESSAGE,
+                  LocalizedFormats.INSUFFICIENT_DATA_FOR_T_STATISTIC,
                   (stat == null) ? 0 : stat.getN());
         }
     }
