@@ -21,8 +21,10 @@ import junit.framework.TestCase;
 
 import java.util.Locale;
 
+import org.apache.commons.math.exception.util.LocalizedFormats;
+
 /**
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1035475 $ $Date: 2010-11-15 23:39:25 +0100 (lun. 15 nov. 2010) $
  */
 public class ConvergenceExceptionTest extends TestCase {
 
@@ -35,11 +37,11 @@ public class ConvergenceExceptionTest extends TestCase {
     }
 
     public void testConstructorPatternArguments(){
-        String pattern = "a {0}x{1} matrix cannot be a rotation matrix";
+        LocalizedFormats pattern = LocalizedFormats.ROTATION_MATRIX_DIMENSIONS;
         Object[] arguments = { Integer.valueOf(6), Integer.valueOf(4) };
         ConvergenceException ex = new ConvergenceException(pattern, arguments);
         assertNull(ex.getCause());
-        assertEquals(pattern, ex.getPattern());
+        assertEquals(pattern, ex.getGeneralPattern());
         assertEquals(arguments.length, ex.getArguments().length);
         for (int i = 0; i < arguments.length; ++i) {
             assertEquals(arguments[i], ex.getArguments()[i]);
@@ -56,13 +58,13 @@ public class ConvergenceExceptionTest extends TestCase {
     }
 
     public void testConstructorPatternArgumentsCause(){
-        String pattern = "a {0}x{1} matrix cannot be a rotation matrix";
+        LocalizedFormats pattern = LocalizedFormats.ROTATION_MATRIX_DIMENSIONS;
         Object[] arguments = { Integer.valueOf(6), Integer.valueOf(4) };
         String inMsg = "inner message";
         Exception cause = new Exception(inMsg);
         ConvergenceException ex = new ConvergenceException(cause, pattern, arguments);
         assertEquals(cause, ex.getCause());
-        assertEquals(pattern, ex.getPattern());
+        assertEquals(pattern, ex.getGeneralPattern());
         assertEquals(arguments.length, ex.getArguments().length);
         for (int i = 0; i < arguments.length; ++i) {
             assertEquals(arguments[i], ex.getArguments()[i]);
