@@ -19,11 +19,15 @@ package org.apache.commons.math;
 
 import java.util.Locale;
 
+import org.apache.commons.math.exception.util.LocalizedFormats;
+
 import junit.framework.TestCase;
 
 /**
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1042336 $ $Date: 2010-12-05 13:40:48 +0100 (dim. 05 déc. 2010) $
+ * @deprecated in 2.2 (to be removed in 3.0)
  */
+@Deprecated
 public class FunctionEvaluationExceptionTest extends TestCase {
 
     public void testConstructor(){
@@ -46,11 +50,11 @@ public class FunctionEvaluationExceptionTest extends TestCase {
     }
 
     public void testConstructorPatternArguments(){
-        String pattern = "evaluation failed for argument = {0}";
+        LocalizedFormats pattern = LocalizedFormats.EVALUATION_FAILED;
         Object[] arguments = { Double.valueOf(0.0) };
         FunctionEvaluationException ex = new FunctionEvaluationException(0.0, pattern, arguments);
         assertNull(ex.getCause());
-        assertEquals(pattern, ex.getPattern());
+        assertEquals(pattern, ex.getGeneralPattern());
         assertEquals(arguments.length, ex.getArguments().length);
         for (int i = 0; i < arguments.length; ++i) {
             assertEquals(arguments[i], ex.getArguments()[i]);
@@ -60,12 +64,12 @@ public class FunctionEvaluationExceptionTest extends TestCase {
     }
 
     public void testConstructorArrayPatternArguments(){
-        String pattern = "evaluation failed for argument = {0}";
+        LocalizedFormats pattern = LocalizedFormats.EVALUATION_FAILED;
         Object[] arguments = { Double.valueOf(0.0) };
         FunctionEvaluationException ex =
             new FunctionEvaluationException(new double[] { 0, 1, 2 }, pattern, arguments);
         assertNull(ex.getCause());
-        assertEquals(pattern, ex.getPattern());
+        assertEquals(pattern, ex.getGeneralPattern());
         assertEquals(arguments.length, ex.getArguments().length);
         for (int i = 0; i < arguments.length; ++i) {
             assertEquals(arguments[i], ex.getArguments()[i]);
@@ -78,13 +82,13 @@ public class FunctionEvaluationExceptionTest extends TestCase {
     }
 
     public void testConstructorPatternArgumentsCause(){
-        String pattern = "evaluation failed for argument = {0}";
+        LocalizedFormats pattern = LocalizedFormats.EVALUATION_FAILED;
         Object[] arguments = { Double.valueOf(0.0) };
         String inMsg = "inner message";
         Exception cause = new Exception(inMsg);
         FunctionEvaluationException ex = new FunctionEvaluationException(cause, 0.0, pattern, arguments);
         assertEquals(cause, ex.getCause());
-        assertEquals(pattern, ex.getPattern());
+        assertEquals(pattern, ex.getGeneralPattern());
         assertEquals(arguments.length, ex.getArguments().length);
         for (int i = 0; i < arguments.length; ++i) {
             assertEquals(arguments[i], ex.getArguments()[i]);
@@ -94,14 +98,14 @@ public class FunctionEvaluationExceptionTest extends TestCase {
     }
 
     public void testConstructorArrayPatternArgumentsCause(){
-        String pattern = "evaluation failed for argument = {0}";
+        LocalizedFormats pattern = LocalizedFormats.EVALUATION_FAILED;
         Object[] arguments = { Double.valueOf(0.0) };
         String inMsg = "inner message";
         Exception cause = new Exception(inMsg);
         FunctionEvaluationException ex =
             new FunctionEvaluationException(cause, new double[] { 0, 1, 2 }, pattern, arguments);
         assertEquals(cause, ex.getCause());
-        assertEquals(pattern, ex.getPattern());
+        assertEquals(pattern, ex.getGeneralPattern());
         assertEquals(arguments.length, ex.getArguments().length);
         for (int i = 0; i < arguments.length; ++i) {
             assertEquals(arguments[i], ex.getArguments()[i]);
