@@ -16,24 +16,23 @@
  */
 package org.apache.commons.math.analysis;
 
-import org.apache.commons.math.FunctionEvaluationException;
+import org.apache.commons.math.util.FastMath;
 
 /**
- * Auxillary class for testing purposes.
+ * Auxiliary class for testing purposes.
  *
- * @version $Revision: 786927 $ $Date: 2009-06-20 19:37:47 -0400 (Sat, 20 Jun 2009) $
+ * @version $Revision: 1037327 $ $Date: 2010-11-20 21:57:37 +0100 (sam. 20 nov. 2010) $
  */
 public class Expm1Function implements DifferentiableUnivariateRealFunction {
 
-    public double value(double x) throws FunctionEvaluationException {
-        // Math.expm1() is available in jdk 1.5 but not in jdk 1.4.2.
-        return Math.exp(x) - 1.0;
+    public double value(double x) {
+        return FastMath.expm1(x);
     }
 
     public UnivariateRealFunction derivative() {
         return new UnivariateRealFunction() {
-            public double value(double x) throws FunctionEvaluationException {
-                return Math.exp(x);
+            public double value(double x) {
+                return FastMath.exp(x);
             }
         };
     }
