@@ -16,7 +16,7 @@
  */
 package org.apache.commons.math.analysis;
 
-import org.apache.commons.math.FunctionEvaluationException;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Auxillary class for testing solvers.
@@ -26,23 +26,23 @@ import org.apache.commons.math.FunctionEvaluationException;
  * which means linear approximation (Regula Falsi) will converge
  * quadratically.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1037327 $ $Date: 2010-11-20 21:57:37 +0100 (sam. 20 nov. 2010) $
  */
 public class SinFunction implements DifferentiableUnivariateRealFunction {
 
     /* Evaluate sinus fuction.
      * @see org.apache.commons.math.UnivariateRealFunction#value(double)
      */
-    public double value(double x) throws FunctionEvaluationException {
-        return Math.sin(x);
+    public double value(double x) {
+        return FastMath.sin(x);
     }
 
     /* First derivative of sinus function
      */
     public UnivariateRealFunction derivative() {
         return new UnivariateRealFunction() {
-            public double value(double x) throws FunctionEvaluationException {
-                return Math.cos(x);
+            public double value(double x) {
+                return FastMath.cos(x);
             }
         };
     }
