@@ -20,6 +20,7 @@ import org.apache.commons.math.MathException;
 import org.apache.commons.math.analysis.QuinticFunction;
 import org.apache.commons.math.analysis.SinFunction;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
@@ -29,7 +30,7 @@ import junit.framework.TestCase;
  * Test runs show that for a default relative accuracy of 1E-6, it
  * generally takes 10 to 15 iterations for the integral to converge.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public final class TrapezoidIntegratorTest extends TestCase {
 
@@ -41,13 +42,13 @@ public final class TrapezoidIntegratorTest extends TestCase {
         UnivariateRealIntegrator integrator = new TrapezoidIntegrator();
         double min, max, expected, result, tolerance;
 
-        min = 0; max = Math.PI; expected = 2;
-        tolerance = Math.abs(expected * integrator.getRelativeAccuracy());
+        min = 0; max = FastMath.PI; expected = 2;
+        tolerance = FastMath.abs(expected * integrator.getRelativeAccuracy());
         result = integrator.integrate(f, min, max);
         assertEquals(expected, result, tolerance);
 
-        min = -Math.PI/3; max = 0; expected = -0.5;
-        tolerance = Math.abs(expected * integrator.getRelativeAccuracy());
+        min = -FastMath.PI/3; max = 0; expected = -0.5;
+        tolerance = FastMath.abs(expected * integrator.getRelativeAccuracy());
         result = integrator.integrate(f, min, max);
         assertEquals(expected, result, tolerance);
     }
@@ -61,17 +62,17 @@ public final class TrapezoidIntegratorTest extends TestCase {
         double min, max, expected, result, tolerance;
 
         min = 0; max = 1; expected = -1.0/48;
-        tolerance = Math.abs(expected * integrator.getRelativeAccuracy());
+        tolerance = FastMath.abs(expected * integrator.getRelativeAccuracy());
         result = integrator.integrate(f, min, max);
         assertEquals(expected, result, tolerance);
 
         min = 0; max = 0.5; expected = 11.0/768;
-        tolerance = Math.abs(expected * integrator.getRelativeAccuracy());
+        tolerance = FastMath.abs(expected * integrator.getRelativeAccuracy());
         result = integrator.integrate(f, min, max);
         assertEquals(expected, result, tolerance);
 
         min = -1; max = 4; expected = 2048/3.0 - 78 + 1.0/48;
-        tolerance = Math.abs(expected * integrator.getRelativeAccuracy());
+        tolerance = FastMath.abs(expected * integrator.getRelativeAccuracy());
         result = integrator.integrate(f, min, max);
         assertEquals(expected, result, tolerance);
     }
