@@ -20,6 +20,8 @@ import org.apache.commons.math.MathException;
 import org.apache.commons.math.analysis.Expm1Function;
 import org.apache.commons.math.analysis.SinFunction;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
+import org.apache.commons.math.FunctionEvaluationException;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
@@ -35,7 +37,7 @@ import junit.framework.TestCase;
  * it and use the absolute value upper bound for estimates. For reference,
  * see <b>Introduction to Numerical Analysis</b>, ISBN 038795452X, chapter 2.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1073498 $ $Date: 2011-02-22 21:57:26 +0100 (mar. 22 févr. 2011) $
  */
 public final class NevilleInterpolatorTest extends TestCase {
 
@@ -51,7 +53,7 @@ public final class NevilleInterpolatorTest extends TestCase {
 
         // 6 interpolating points on interval [0, 2*PI]
         int n = 6;
-        double min = 0.0, max = 2 * Math.PI;
+        double min = 0.0, max = 2 * FastMath.PI;
         x = new double[n];
         y = new double[n];
         for (int i = 0; i < n; i++) {
@@ -61,12 +63,12 @@ public final class NevilleInterpolatorTest extends TestCase {
         double derivativebound = 1.0;
         UnivariateRealFunction p = interpolator.interpolate(x, y);
 
-        z = Math.PI / 4; expected = f.value(z); result = p.value(z);
-        tolerance = Math.abs(derivativebound * partialerror(x, z));
+        z = FastMath.PI / 4; expected = f.value(z); result = p.value(z);
+        tolerance = FastMath.abs(derivativebound * partialerror(x, z));
         assertEquals(expected, result, tolerance);
 
-        z = Math.PI * 1.5; expected = f.value(z); result = p.value(z);
-        tolerance = Math.abs(derivativebound * partialerror(x, z));
+        z = FastMath.PI * 1.5; expected = f.value(z); result = p.value(z);
+        tolerance = FastMath.abs(derivativebound * partialerror(x, z));
         assertEquals(expected, result, tolerance);
     }
 
@@ -89,19 +91,19 @@ public final class NevilleInterpolatorTest extends TestCase {
             x[i] = min + i * (max - min) / n;
             y[i] = f.value(x[i]);
         }
-        double derivativebound = Math.E;
+        double derivativebound = FastMath.E;
         UnivariateRealFunction p = interpolator.interpolate(x, y);
 
         z = 0.0; expected = f.value(z); result = p.value(z);
-        tolerance = Math.abs(derivativebound * partialerror(x, z));
+        tolerance = FastMath.abs(derivativebound * partialerror(x, z));
         assertEquals(expected, result, tolerance);
 
         z = 0.5; expected = f.value(z); result = p.value(z);
-        tolerance = Math.abs(derivativebound * partialerror(x, z));
+        tolerance = FastMath.abs(derivativebound * partialerror(x, z));
         assertEquals(expected, result, tolerance);
 
         z = -0.5; expected = f.value(z); result = p.value(z);
-        tolerance = Math.abs(derivativebound * partialerror(x, z));
+        tolerance = FastMath.abs(derivativebound * partialerror(x, z));
         assertEquals(expected, result, tolerance);
     }
 
@@ -117,8 +119,8 @@ public final class NevilleInterpolatorTest extends TestCase {
             double y[] = { 0.0, 4.0, 4.0, 2.5 };
             UnivariateRealFunction p = interpolator.interpolate(x, y);
             p.value(0.0);
-            fail("Expecting MathException - bad abscissas array");
-        } catch (MathException ex) {
+            fail("Expecting FunctionEvaluationException - bad abscissas array");
+        } catch (FunctionEvaluationException ex) {
             // expected
         }
     }
