@@ -16,7 +16,8 @@
  */
 package org.apache.commons.math.analysis.polynomials;
 
-import org.apache.commons.math.MathException;
+import org.apache.commons.math.FunctionEvaluationException;
+
 import junit.framework.TestCase;
 
 /**
@@ -24,14 +25,14 @@ import junit.framework.TestCase;
  * <p>
  * The small tolerance number is used only to account for round-off errors.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1073498 $ $Date: 2011-02-22 21:57:26 +0100 (mar. 22 févr. 2011) $
  */
 public final class PolynomialFunctionNewtonFormTest extends TestCase {
 
     /**
      * Test of polynomial for the linear function.
      */
-    public void testLinearFunction() throws MathException {
+    public void testLinearFunction() throws FunctionEvaluationException {
         PolynomialFunctionNewtonForm p;
         double coefficients[], z, expected, result, tolerance = 1E-12;
 
@@ -60,7 +61,7 @@ public final class PolynomialFunctionNewtonFormTest extends TestCase {
     /**
      * Test of polynomial for the quadratic function.
      */
-    public void testQuadraticFunction() throws MathException {
+    public void testQuadraticFunction() throws FunctionEvaluationException {
         PolynomialFunctionNewtonForm p;
         double coefficients[], z, expected, result, tolerance = 1E-12;
 
@@ -90,7 +91,7 @@ public final class PolynomialFunctionNewtonFormTest extends TestCase {
     /**
      * Test of polynomial for the quintic function.
      */
-    public void testQuinticFunction() throws MathException {
+    public void testQuinticFunction() throws FunctionEvaluationException {
         PolynomialFunctionNewtonForm p;
         double coefficients[], z, expected, result, tolerance = 1E-12;
 
