@@ -16,16 +16,15 @@
  */
 package org.apache.commons.math.analysis.polynomials;
 
-// commons-math
-import org.apache.commons.math.MathException;
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.util.FastMath;
 // junit
 import junit.framework.TestCase;
 
 /**
  * Tests the PolynomialFunction implementation of a UnivariateRealFunction.
  *
- * @version $Revision: 917261 $
+ * @version $Revision: 1070725 $
  * @author Matt Cliff <matt@mattcliff.com>
  */
 public final class PolynomialFunctionTest extends TestCase {
@@ -38,7 +37,7 @@ public final class PolynomialFunctionTest extends TestCase {
      *
      * <p>value of this is 2.5 everywhere.</p>
      */
-    public void testConstants() throws MathException {
+    public void testConstants() throws Exception {
         double[] c = { 2.5 };
         PolynomialFunction f = new PolynomialFunction( c );
 
@@ -64,7 +63,7 @@ public final class PolynomialFunctionTest extends TestCase {
      *      f(0.5) = 0.0, f(1.5) = 3.0</tt> and <tt>f(3.0) = 7.5</tt>
      * </p>
      */
-    public void testLinear() throws MathException {
+    public void testLinear() throws Exception {
         double[] c = { -1.5, 3.0 };
         PolynomialFunction f = new PolynomialFunction( c );
 
@@ -138,7 +137,7 @@ public final class PolynomialFunctionTest extends TestCase {
      * <tt>f(x) = x^3 - 2x^2 + 6x + 3, g(x) = 3x^2 - 4x + 6</tt>
      * and <tt>h(x) = 6x - 4</tt>
      */
-    public void testfirstDerivativeComparison() throws MathException {
+    public void testfirstDerivativeComparison() throws Exception {
         double[] f_coeff = { 3.0, 6.0, -2.0, 1.0 };
         double[] g_coeff = { 6.0, -4.0, 3.0 };
         double[] h_coeff = { -4.0, 6.0 };
@@ -155,8 +154,8 @@ public final class PolynomialFunctionTest extends TestCase {
         assertEquals( f.derivative().value(-3.25), g.value(-3.25), tolerance );
 
         // compare g' = h
-        assertEquals( g.derivative().value(Math.PI), h.value(Math.PI), tolerance );
-        assertEquals( g.derivative().value(Math.E),  h.value(Math.E),  tolerance );
+        assertEquals( g.derivative().value(FastMath.PI), h.value(FastMath.PI), tolerance );
+        assertEquals( g.derivative().value(FastMath.E),  h.value(FastMath.E),  tolerance );
 
     }
 
@@ -238,7 +237,7 @@ public final class PolynomialFunctionTest extends TestCase {
      * <tt>f(x) = x^3 - 2x^2 + 6x + 3, g(x) = 3x^2 - 4x + 6</tt>
      * and <tt>h(x) = 6x - 4</tt>
      */
-    public void testMath341() throws MathException {
+    public void testMath341() throws Exception {
         double[] f_coeff = { 3.0, 6.0, -2.0, 1.0 };
         double[] g_coeff = { 6.0, -4.0, 3.0 };
         double[] h_coeff = { -4.0, 6.0 };
@@ -255,8 +254,8 @@ public final class PolynomialFunctionTest extends TestCase {
         assertEquals( f.derivative().value(-3.25), g.value(-3.25), tolerance );
 
         // compare g' = h
-        assertEquals( g.derivative().value(Math.PI), h.value(Math.PI), tolerance );
-        assertEquals( g.derivative().value(Math.E),  h.value(Math.E),  tolerance );
+        assertEquals( g.derivative().value(FastMath.PI), h.value(FastMath.PI), tolerance );
+        assertEquals( g.derivative().value(FastMath.E),  h.value(FastMath.E),  tolerance );
     }
 
     public void checkPolynomial(PolynomialFunction p, String reference) {
