@@ -19,13 +19,13 @@ package org.apache.commons.math.analysis.polynomials;
 import java.util.Arrays;
 import junit.framework.TestCase;
 
-import org.apache.commons.math.FunctionEvaluationException;
+import org.apache.commons.math.ArgumentOutsideDomainException;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
 
 /**
  * Tests the PolynomialSplineFunction implementation.
  *
- * @version $Revision: 811685 $
+ * @version $Revision: 1042508 $
  */
 public class PolynomialSplineFunctionTest extends TestCase {
 
@@ -116,15 +116,15 @@ public class PolynomialSplineFunctionTest extends TestCase {
 
         try { //outside of domain -- under min
             x = spline.value(-1.5);
-            fail("Expecting IllegalArgumentException");
-        } catch (FunctionEvaluationException ex) {
+            fail("Expecting ArgumentOutsideDomainException");
+        } catch (ArgumentOutsideDomainException ex) {
             // expected
         }
 
         try { //outside of domain -- over max
             x = spline.value(2.5);
-            fail("Expecting IllegalArgumentException");
-        } catch (FunctionEvaluationException ex) {
+            fail("Expecting ArgumentOutsideDomainException");
+        } catch (ArgumentOutsideDomainException ex) {
             // expected
         }
     }
