@@ -20,11 +20,12 @@ import org.apache.commons.math.MathException;
 import org.apache.commons.math.analysis.QuinticFunction;
 import org.apache.commons.math.analysis.SinFunction;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
 /**
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public final class BisectionSolverTest extends TestCase {
 
@@ -35,10 +36,10 @@ public final class BisectionSolverTest extends TestCase {
 
         UnivariateRealSolver solver = new BisectionSolver(f);
         result = solver.solve(3, 4);
-        assertEquals(result, Math.PI, solver.getAbsoluteAccuracy());
+        assertEquals(result, FastMath.PI, solver.getAbsoluteAccuracy());
 
         result = solver.solve(1, 4);
-        assertEquals(result, Math.PI, solver.getAbsoluteAccuracy());
+        assertEquals(result, FastMath.PI, solver.getAbsoluteAccuracy());
     }
 
     public void testSinZero() throws MathException {
@@ -47,10 +48,10 @@ public final class BisectionSolverTest extends TestCase {
 
         UnivariateRealSolver solver = new BisectionSolver();
         result = solver.solve(f, 3, 4);
-        assertEquals(result, Math.PI, solver.getAbsoluteAccuracy());
+        assertEquals(result, FastMath.PI, solver.getAbsoluteAccuracy());
 
         result = solver.solve(f, 1, 4);
-        assertEquals(result, Math.PI, solver.getAbsoluteAccuracy());
+        assertEquals(result, FastMath.PI, solver.getAbsoluteAccuracy());
     }
 
    public void testQuinticZero() throws MathException {
@@ -95,6 +96,12 @@ public final class BisectionSolverTest extends TestCase {
         assertTrue(solver.getIterationCount() > 0);
     }
 
+    public void testMath369() throws Exception {
+        UnivariateRealFunction f = new SinFunction();
+        UnivariateRealSolver solver = new BisectionSolver();
+        assertEquals(FastMath.PI, solver.solve(f, 3.0, 3.2, 3.1), solver.getAbsoluteAccuracy());
+    }
+
     /**
      *
      */
