@@ -21,6 +21,7 @@ import org.apache.commons.math.analysis.Expm1Function;
 import org.apache.commons.math.analysis.QuinticFunction;
 import org.apache.commons.math.analysis.SinFunction;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
@@ -33,7 +34,7 @@ import junit.framework.TestCase;
  * initial bracket and 5 to 10 iterations for distant initial bracket
  * to converge.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public final class RiddersSolverTest extends TestCase {
 
@@ -46,15 +47,15 @@ public final class RiddersSolverTest extends TestCase {
         UnivariateRealSolver solver = new RiddersSolver(f);
         double min, max, expected, result, tolerance;
 
-        min = 3.0; max = 4.0; expected = Math.PI;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        min = 3.0; max = 4.0; expected = FastMath.PI;
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(min, max);
         assertEquals(expected, result, tolerance);
 
         min = -1.0; max = 1.5; expected = 0.0;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(min, max);
         assertEquals(expected, result, tolerance);
     }
@@ -67,15 +68,15 @@ public final class RiddersSolverTest extends TestCase {
         UnivariateRealSolver solver = new RiddersSolver();
         double min, max, expected, result, tolerance;
 
-        min = 3.0; max = 4.0; expected = Math.PI;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        min = 3.0; max = 4.0; expected = FastMath.PI;
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
 
         min = -1.0; max = 1.5; expected = 0.0;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
     }
@@ -89,20 +90,20 @@ public final class RiddersSolverTest extends TestCase {
         double min, max, expected, result, tolerance;
 
         min = -0.4; max = 0.2; expected = 0.0;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
 
         min = 0.75; max = 1.5; expected = 1.0;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
 
         min = -0.9; max = -0.2; expected = -0.5;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
     }
@@ -116,20 +117,20 @@ public final class RiddersSolverTest extends TestCase {
         double min, max, expected, result, tolerance;
 
         min = -1.0; max = 2.0; expected = 0.0;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
 
         min = -20.0; max = 10.0; expected = 0.0;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
 
         min = -50.0; max = 100.0; expected = 0.0;
-        tolerance = Math.max(solver.getAbsoluteAccuracy(),
-                    Math.abs(expected * solver.getRelativeAccuracy()));
+        tolerance = FastMath.max(solver.getAbsoluteAccuracy(),
+                    FastMath.abs(expected * solver.getRelativeAccuracy()));
         result = solver.solve(f, min, max);
         assertEquals(expected, result, tolerance);
     }
