@@ -18,18 +18,19 @@
 package org.apache.commons.math.complex;
 
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
 /**
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public class ComplexUtilsTest extends TestCase {
 
     private double inf = Double.POSITIVE_INFINITY;
     private double negInf = Double.NEGATIVE_INFINITY;
     private double nan = Double.NaN;
-    private double pi = Math.PI;
+    private double pi = FastMath.PI;
 
     private Complex negInfInf = new Complex(negInf, inf);
     private Complex infNegInf = new Complex(inf, negInf);
