@@ -16,12 +16,14 @@
  */
 package org.apache.commons.math.distribution;
 
+import org.apache.commons.math.util.FastMath;
+
 /**
  * Test cases for ExponentialDistribution.
  * Extends ContinuousDistributionAbstractTest.  See class javadoc for
  * ContinuousDistributionAbstractTest for details.
  *
- * @version $Revision: 924362 $ $Date: 2010-03-17 12:45:31 -0400 (Wed, 17 Mar 2010) $
+ * @version $Revision: 1054524 $ $Date: 2011-01-03 05:59:18 +0100 (lun. 03 janv. 2011) $
  */
 public class ExponentialDistributionTest extends ContinuousDistributionAbstractTest {
 
@@ -94,8 +96,8 @@ public class ExponentialDistributionTest extends ContinuousDistributionAbstractT
         assertEquals(0.0, d1.density(-1e-9));
         assertEquals(1.0, d1.density(0.0));
         assertEquals(0.0, d1.density(1000.0));
-        assertEquals(Math.exp(-1), d1.density(1.0));
-        assertEquals(Math.exp(-2), d1.density(2.0));
+        assertEquals(FastMath.exp(-1), d1.density(1.0));
+        assertEquals(FastMath.exp(-2), d1.density(2.0));
 
         ExponentialDistribution d2 = new ExponentialDistributionImpl(3);
         assertEquals(1/3.0, d2.density(0.0));
@@ -119,4 +121,17 @@ public class ExponentialDistributionTest extends ContinuousDistributionAbstractT
         }
     }
 
+
+    public void testMomonts() {
+        final double tol = 1e-9;
+        ExponentialDistributionImpl dist;
+        
+        dist = new ExponentialDistributionImpl(11d);
+        assertEquals(dist.getNumericalMean(), 11d, tol);
+        assertEquals(dist.getNumericalVariance(), 11d * 11d, tol);
+        
+        dist.setMean(10.5d);
+        assertEquals(dist.getNumericalMean(), 10.5d, tol);
+        assertEquals(dist.getNumericalVariance(), 10.5d * 10.5d, tol);
+    }
 }
