@@ -22,7 +22,7 @@ package org.apache.commons.math.distribution;
  * Extends ContinuousDistributionAbstractTest.  See class javadoc for
  * ContinuousDistributionAbstractTest for details.
  *
- * @version $Revision: 924362 $ $Date: 2010-03-17 12:45:31 -0400 (Wed, 17 Mar 2010) $
+ * @version $Revision: 1054524 $ $Date: 2011-01-03 05:59:18 +0100 (lun. 03 janv. 2011) $
  */
 public class FDistributionTest extends ContinuousDistributionAbstractTest {
 
@@ -129,4 +129,22 @@ public class FDistributionTest extends ContinuousDistributionAbstractTest {
         assertEquals(0.975, x, 1.0e-5);
     }
 
+    public void testMomonts() {
+        final double tol = 1e-9;
+        FDistributionImpl dist;
+        
+        dist = new FDistributionImpl(1, 2);
+        assertTrue(Double.isNaN(dist.getNumericalMean()));
+        assertTrue(Double.isNaN(dist.getNumericalVariance())); 
+        
+        dist.setNumeratorDegreesOfFreedom(1);
+        dist.setDenominatorDegreesOfFreedom(3);
+        assertEquals(dist.getNumericalMean(), 3d / (3d - 2d), tol);
+        assertTrue(Double.isNaN(dist.getNumericalVariance()));
+        
+        dist.setNumeratorDegreesOfFreedom(1);
+        dist.setDenominatorDegreesOfFreedom(5);
+        assertEquals(dist.getNumericalMean(), 5d / (5d - 2d), tol);
+        assertEquals(dist.getNumericalVariance(), (2d * 5d * 5d * 4d) / 9d, tol);        
+    }
 }
