@@ -22,7 +22,7 @@ package org.apache.commons.math.distribution;
  * Extends ContinuousDistributionAbstractTest.  See class javadoc for
  * ContinuousDistributionAbstractTest for details.
  *
- * @version $Revision: 924362 $ $Date: 2010-03-17 12:45:31 -0400 (Wed, 17 Mar 2010) $
+ * @version $Revision: 1054524 $ $Date: 2011-01-03 05:59:18 +0100 (lun. 03 janv. 2011) $
  */
 public class GammaDistributionTest extends ContinuousDistributionAbstractTest {
 
@@ -152,4 +152,18 @@ public class GammaDistributionTest extends ContinuousDistributionAbstractTest {
         setInverseCumulativeTestValues(new double[] {0, Double.POSITIVE_INFINITY});
         verifyInverseCumulativeProbabilities();
     }
+
+    public void testMomonts() {
+        final double tol = 1e-9;
+        GammaDistributionImpl dist;
+        
+        dist = new GammaDistributionImpl(1, 2);
+        assertEquals(dist.getNumericalMean(), 2, tol);
+        assertEquals(dist.getNumericalVariance(), 4, tol); 
+        
+        dist.setAlpha(1.1);
+        dist.setBeta(4.2);        
+        assertEquals(dist.getNumericalMean(), 1.1d * 4.2d, tol);
+        assertEquals(dist.getNumericalVariance(), 1.1d * 4.2d * 4.2d, tol);
+    }
 }
