@@ -16,6 +16,9 @@
  */
 package org.apache.commons.math.distribution;
 
+import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.util.FastMath;
+
 import junit.framework.TestCase;
 
 /**
@@ -38,7 +41,7 @@ import junit.framework.TestCase;
  *  use the setXxx methods for the instance data in test cases and call the verifyXxx methods
  *  to verify results.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public abstract class IntegerDistributionAbstractTest extends TestCase {
 
@@ -210,8 +213,8 @@ public abstract class IntegerDistributionAbstractTest extends TestCase {
                            cumulativeTestPoints[i],
                            cumulativeTestPoints[i + 1]),
                    distribution.cumulativeProbability(arg, arg2), tolerance);
-                arg = arg - Math.random();
-                arg2 = arg2 + Math.random();
+                arg = arg - FastMath.random();
+                arg2 = arg2 + FastMath.random();
                 assertEquals("Inconsistent probability for discrete range " +
                         "[ " + arg + "," + arg2 + " ]",
                    distribution.cumulativeProbability(
@@ -269,6 +272,32 @@ public abstract class IntegerDistributionAbstractTest extends TestCase {
             // expected
         }
     }
+    
+    /**
+     * Test sampling
+     */
+    public void testSampling() throws Exception {
+        int[] densityPoints = makeDensityTestPoints();
+        double[] densityValues = makeDensityTestValues();
+        int sampleSize = 1000;
+        int length = TestUtils.eliminateZeroMassPoints(densityPoints, densityValues);
+        AbstractIntegerDistribution distribution = (AbstractIntegerDistribution) makeDistribution();
+        double[] expectedCounts = new double[length];
+        long[] observedCounts = new long[length];
+        for (int i = 0; i < length; i++) {
+            expectedCounts[i] = sampleSize * densityValues[i];
+        }
+        distribution.reseedRandomGenerator(1000); // Use fixed seed
+        int[] sample = distribution.sample(sampleSize);
+        for (int i = 0; i < sampleSize; i++) {
+          for (int j = 0; j < length; j++) {
+              if (sample[i] == densityPoints[j]) {
+                  observedCounts[j]++;
+              }
+          }
+        }
+        TestUtils.assertChiSquareAccept(densityPoints, expectedCounts, observedCounts, .001);
+    }
 
     //------------------ Getters / Setters for test instance data -----------
     /**
