@@ -21,7 +21,7 @@ package org.apache.commons.math.distribution;
  * Extends IntegerDistributionAbstractTest.  See class javadoc for
  * IntegerDistributionAbstractTest for details.
  *
- * @version $Revision: 924351 $ $Date: 2010-03-17 12:19:29 -0400 (Wed, 17 Mar 2010) $
+ * @version $Revision: 1054524 $ $Date: 2011-01-03 05:59:18 +0100 (lun. 03 janv. 2011) $
  */
 public class PascalDistributionTest extends IntegerDistributionAbstractTest {
 
@@ -119,4 +119,18 @@ public class PascalDistributionTest extends IntegerDistributionAbstractTest {
         verifyCumulativeProbabilities();
         verifyInverseCumulativeProbabilities();
     }
+
+    public void testMomonts() {
+        final double tol = 1e-9;
+        PascalDistributionImpl dist;
+        
+        dist = new PascalDistributionImpl(10, 0.5);
+        assertEquals(dist.getNumericalMean(), ( 10d * 0.5d ) / 0.5d, tol);
+        assertEquals(dist.getNumericalVariance(), ( 10d * 0.5d ) / (0.5d * 0.5d), tol); 
+        
+        dist.setNumberOfSuccesses(25);
+        dist.setProbabilityOfSuccess(0.3);
+        assertEquals(dist.getNumericalMean(), ( 25d * 0.3d ) / 0.7d, tol);
+        assertEquals(dist.getNumericalVariance(), ( 25d * 0.3d ) / (0.7d * 0.7d), tol);
+    }
 }
