@@ -17,12 +17,14 @@
 
 package org.apache.commons.math.distribution;
 
+import org.apache.commons.math.util.FastMath;
+
 /**
  * Test cases for {@link ZipfDistribution}.
  * Extends IntegerDistributionAbstractTest.  See class javadoc for
  * IntegerDistributionAbstractTest for details.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1054524 $ $Date: 2011-01-03 05:59:18 +0100 (lun. 03 janv. 2011) $
  */
 public class ZipfDistributionTest extends IntegerDistributionAbstractTest {
     public ZipfDistributionTest(String name) {
@@ -75,4 +77,13 @@ public class ZipfDistributionTest extends IntegerDistributionAbstractTest {
     public int[] makeInverseCumulativeTestValues() {
         return new int[] {0, 0, 0, 0, 0, 0, 1, 9, 9, 9, 8, 7, 10};
     }
+
+    public void testMomonts() {
+        final double tol = 1e-9;
+        ZipfDistributionImpl dist;
+        
+        dist = new ZipfDistributionImpl(2, 0.5);
+        assertEquals(dist.getNumericalMean(), FastMath.sqrt(2), tol);
+        assertEquals(dist.getNumericalVariance(), 0.24264068711928521, tol); 
+    }
 }
