@@ -19,6 +19,7 @@ package org.apache.commons.math.estimation;
 
 import org.apache.commons.math.estimation.EstimatedParameter;
 import org.apache.commons.math.estimation.WeightedMeasurement;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.*;
 
@@ -79,7 +80,7 @@ public class WeightedMeasurementTest
   }
 
   private void checkValue(double value, double expected) {
-   assertTrue(Math.abs(value - expected) < 1.0e-10);
+   assertTrue(FastMath.abs(value - expected) < 1.0e-10);
   }
 
   private double theoretical() {
