@@ -21,6 +21,7 @@ import java.math.BigInteger;
 
 import org.apache.commons.math.ConvergenceException;
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
@@ -64,21 +65,25 @@ public class BigFractionTest extends TestCase {
         assertFraction(1055531162664967l, 70368744177664l, new BigFraction(15.0000000000001));
         try {
             new BigFraction(null, BigInteger.ONE);
+            fail("Expecting NullPointerException");
         } catch (NullPointerException npe) {
             // expected
         }
         try {
             new BigFraction(BigInteger.ONE, null);
+            fail("Expecting NullPointerException");
         } catch (NullPointerException npe) {
             // expected
         }
         try {
             new BigFraction(BigInteger.ONE, BigInteger.ZERO);
+            fail("Expecting ArithmeticException");
         } catch (ArithmeticException npe) {
             // expected
         }
         try {
             new BigFraction(2.0 * Integer.MAX_VALUE, 1.0e-5, 100000);
+            fail("Expecting FractionConversionException");
         } catch (FractionConversionException fce) {
             // expected
         }
@@ -88,12 +93,10 @@ public class BigFractionTest extends TestCase {
         try {
             // the golden ratio is notoriously a difficult number for continuous
             // fraction
-            new BigFraction((1 + Math.sqrt(5)) / 2, 1.0e-12, 25);
+            new BigFraction((1 + FastMath.sqrt(5)) / 2, 1.0e-12, 25);
             fail("an exception should have been thrown");
         } catch (ConvergenceException ce) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
@@ -230,7 +233,7 @@ public class BigFractionTest extends TestCase {
         for (double v : new double[] { Double.NaN, Double.NEGATIVE_INFINITY, Double.POSITIVE_INFINITY}) {
             try {
                 new BigFraction(v);
-                fail("expected exception");
+                fail("Expecting IllegalArgumentException");
             } catch (IllegalArgumentException iae) {
                 // expected
             }
@@ -563,7 +566,7 @@ public class BigFractionTest extends TestCase {
     public void testSerial() throws FractionConversionException {
         BigFraction[] fractions = {
             new BigFraction(3, 4), BigFraction.ONE, BigFraction.ZERO,
-            new BigFraction(17), new BigFraction(Math.PI, 1000),
+            new BigFraction(17), new BigFraction(FastMath.PI, 1000),
             new BigFraction(-5, 2)
         };
         for (BigFraction fraction : fractions) {
