@@ -21,14 +21,15 @@ import java.util.Iterator;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.TestUtils;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
+import org.apache.commons.math.linear.MatrixVisitorException;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Test cases for the {@link ArrayRealVector} class.
  *
- * @version $Revision: 904231 $ $Date: 2010-01-28 14:42:31 -0500 (Thu, 28 Jan 2010) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  */
 public class ArrayRealVectorTest extends TestCase {
 
@@ -61,15 +62,15 @@ public class ArrayRealVectorTest extends TestCase {
             data = d.clone();
         }
 
-        private UnsupportedOperationException unsupported() {
-            return new UnsupportedOperationException("Not supported, unneeded for test purposes");
+        private MatrixVisitorException unsupported() {
+            return new MatrixVisitorException("Not supported, unneeded for test purposes", new Object[0]);
         }
 
-        public RealVector map(UnivariateRealFunction function) throws FunctionEvaluationException {
+        public RealVector map(UnivariateRealFunction function) throws MatrixVisitorException {
             throw unsupported();
         }
 
-        public RealVector mapToSelf(UnivariateRealFunction function) throws FunctionEvaluationException {
+        public RealVector mapToSelf(UnivariateRealFunction function) throws MatrixVisitorException {
             throw unsupported();
         }
 
@@ -537,8 +538,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         RealVector v5_i = new ArrayRealVector(dvec1);
@@ -557,8 +556,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         ArrayRealVector v7 = new ArrayRealVector(v1);
@@ -610,24 +607,6 @@ public class ArrayRealVectorTest extends TestCase {
         assertEquals("testData is 9.0 ", 9.0, v14.getEntry(2));
         assertEquals("testData is 1.0 ", 1.0, v14.getEntry(3));
 
-        try {
-            new ArrayRealVector((double[]) null, false);
-            fail("expected exception");
-        } catch (NullPointerException npe) {
-            // expected
-        } catch (Exception e) {
-            fail("wrong exception caught");
-        }
-
-        try {
-            new ArrayRealVector(new double[0], false);
-            fail("expected exception");
-        } catch (IllegalArgumentException iae) {
-            // expected
-        } catch (Exception e) {
-            fail("wrong exception caught");
-        }
-
    }
 
     public void testDataInOut() {
@@ -679,8 +658,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         ArrayRealVector v_set1 = (ArrayRealVector) v1.copy();
@@ -691,8 +668,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         ArrayRealVector v_set2 = (ArrayRealVector) v4.copy();
@@ -704,8 +679,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         ArrayRealVector v_set3 = (ArrayRealVector) v1.copy();
@@ -717,8 +690,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("ArrayIndexOutOfBoundsException expected");
         } catch (ArrayIndexOutOfBoundsException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         ArrayRealVector v_set4 = (ArrayRealVector) v4.copy();
@@ -730,8 +701,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
 
@@ -1195,8 +1164,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("Expecting ArithmeticException");
         } catch (ArithmeticException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         ArrayRealVector v_unitize = (ArrayRealVector)v1.copy();
@@ -1207,8 +1174,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("Expecting ArithmeticException");
         } catch (ArithmeticException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         ArrayRealVector v_projection = v1.projection(v2);
@@ -1242,8 +1207,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
        try {
@@ -1251,8 +1214,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         try {
@@ -1260,8 +1221,6 @@ public class ArrayRealVectorTest extends TestCase {
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
     }
@@ -1284,7 +1243,7 @@ public class ArrayRealVectorTest extends TestCase {
 
         v.setEntry(0, 0);
         assertEquals(v, new ArrayRealVector(new double[] { 0, 1, 2 }));
-        assertNotSame(v, new ArrayRealVector(new double[] { 0, 1, 2 + Math.ulp(2)}));
+        assertNotSame(v, new ArrayRealVector(new double[] { 0, 1, 2 + FastMath.ulp(2)}));
         assertNotSame(v, new ArrayRealVector(new double[] { 0, 1, 2, 3 }));
 
         assertEquals(new ArrayRealVector(new double[] { Double.NaN, 1, 2 }).hashCode(),
@@ -1307,6 +1266,11 @@ public class ArrayRealVectorTest extends TestCase {
         assertEquals(v,TestUtils.serializeAndRecover(v));
     }
 
+    public void testZeroVectors() {
+        assertEquals(0, new ArrayRealVector(new double[0]).getDimension());
+        assertEquals(0, new ArrayRealVector(new double[0], true).getDimension());
+        assertEquals(0, new ArrayRealVector(new double[0], false).getDimension());
+    }
 
     public void testMinMax()  {
         ArrayRealVector v1 = new ArrayRealVector(new double[] { 0, -6, 4, 12, 7 });
