@@ -22,13 +22,14 @@ import java.util.Random;
 import junit.framework.TestCase;
 
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.linear.MatrixVisitorException;
 import org.apache.commons.math.fraction.Fraction;
 import org.apache.commons.math.fraction.FractionField;
 
 /**
  * Test cases for the {@link BlockFieldMatrix} class.
  *
- * @version $Revision: 902201 $ $Date: 2010-01-22 13:18:16 -0500 (Fri, 22 Jan 2010) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  */
 
 public final class BlockFieldMatrixTest extends TestCase {
@@ -1150,7 +1151,7 @@ public final class BlockFieldMatrixTest extends TestCase {
 
     }
 
-    public void testWalk() {
+    public void testWalk() throws MatrixVisitorException {
         int rows    = 150;
         int columns = 75;
 
