@@ -22,11 +22,13 @@ import java.util.Random;
 import junit.framework.TestCase;
 
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.linear.MatrixVisitorException;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Test cases for the {@link BlockRealMatrix} class.
  *
- * @version $Revision: 902201 $ $Date: 2010-01-22 13:18:16 -0500 (Fri, 22 Jan 2010) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  */
 
 public final class BlockRealMatrixTest extends TestCase {
@@ -157,8 +159,8 @@ public final class BlockRealMatrixTest extends TestCase {
     public void testFrobeniusNorm() {
         BlockRealMatrix m = new BlockRealMatrix(testData);
         BlockRealMatrix m2 = new BlockRealMatrix(testData2);
-        assertEquals("testData Frobenius norm", Math.sqrt(117.0), m.getFrobeniusNorm(), entryTolerance);
-        assertEquals("testData2 Frobenius norm", Math.sqrt(52.0), m2.getFrobeniusNorm(), entryTolerance);
+        assertEquals("testData Frobenius norm", FastMath.sqrt(117.0), m.getFrobeniusNorm(), entryTolerance);
+        assertEquals("testData2 Frobenius norm", FastMath.sqrt(52.0), m2.getFrobeniusNorm(), entryTolerance);
     }
 
      /** test m-n = m + -n */
@@ -1061,7 +1063,7 @@ public final class BlockRealMatrixTest extends TestCase {
 
     }
 
-    public void testWalk() {
+    public void testWalk() throws MatrixVisitorException {
         int rows    = 150;
         int columns = 75;
 
