@@ -17,19 +17,22 @@
 
 package org.apache.commons.math.linear;
 
+import org.apache.commons.math.exception.util.LocalizedFormats;
+
 import junit.framework.TestCase;
 
 /**
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 983921 $ $Date: 2010-08-10 12:46:06 +0200 (mar. 10 août 2010) $
  */
 public class MatrixIndexExceptionTest extends TestCase {
 
     /**
      *
      */
-    public void testConstructorMessage(){
-        String msg = "message";
-        MatrixIndexException ex = new MatrixIndexException(msg);
-        assertEquals(msg, ex.getMessage());
+    public void testParameter(){
+        MatrixIndexException ex = new MatrixIndexException(LocalizedFormats.INDEX_OUT_OF_RANGE, 12, 0, 5);
+        assertEquals(12, ex.getArguments()[0]);
+        assertEquals(0,  ex.getArguments()[1]);
+        assertEquals(5,  ex.getArguments()[2]);
     }
 }
