@@ -27,7 +27,7 @@ import junit.framework.TestCase;
 /**
  * Test cases for the {@link SparseFieldVector} class.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1003907 $ $Date: 2010-10-03 00:23:34 +0200 (dim. 03 oct. 2010) $
  */
 public class SparseFieldVectorTest extends TestCase {
 
@@ -178,8 +178,6 @@ public class SparseFieldVectorTest extends TestCase {
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
 
