@@ -21,14 +21,15 @@ import java.util.Iterator;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.TestUtils;
 import org.apache.commons.math.analysis.UnivariateRealFunction;
+import org.apache.commons.math.linear.MatrixVisitorException;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Test cases for the {@link OpenMapRealVector} class.
  *
- * @version $Revision: 902203 $ $Date: 2010-01-22 13:27:41 -0500 (Fri, 22 Jan 2010) $
+ * @version $Revision: 1073158 $ $Date: 2011-02-21 22:46:52 +0100 (lun. 21 févr. 2011) $
  */
 public class SparseRealVectorTest extends TestCase {
 
@@ -59,17 +60,17 @@ public class SparseRealVectorTest extends TestCase {
             data = d.clone();
         }
 
-        private UnsupportedOperationException unsupported() {
-            return new UnsupportedOperationException("Not supported, unneeded for test purposes");
+        private MatrixVisitorException unsupported() {
+            return new MatrixVisitorException("Not supported, unneeded for test purposes", new Object[0]);
         }
 
         @Override
-        public RealVector map(UnivariateRealFunction function) throws FunctionEvaluationException {
+        public RealVector map(UnivariateRealFunction function) throws MatrixVisitorException {
             throw unsupported();
         }
 
         @Override
-        public RealVector mapToSelf(UnivariateRealFunction function) throws FunctionEvaluationException {
+        public RealVector mapToSelf(UnivariateRealFunction function) throws MatrixVisitorException {
             throw unsupported();
         }
 
@@ -581,8 +582,6 @@ public class SparseRealVectorTest extends TestCase {
         //    fail("IllegalArgumentException expected");
         //} catch (IllegalArgumentException ex) {
             // expected behavior
-        //} catch (Exception e) {
-        //    fail("wrong exception caught");
         //}
 
         RealVector v5_i = new OpenMapRealVector(dvec1);
@@ -640,8 +639,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         OpenMapRealVector v_set1 = v1.copy();
@@ -652,8 +649,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         OpenMapRealVector v_set2 = v4.copy();
@@ -665,8 +660,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         OpenMapRealVector v_set3 = v1.copy();
@@ -678,8 +671,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         OpenMapRealVector v_set4 = v4.copy();
@@ -691,8 +682,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("MatrixIndexException expected");
         } catch (MatrixIndexException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
 
@@ -1128,8 +1117,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("Expecting ArithmeticException");
         } catch (ArithmeticException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         OpenMapRealVector v_unitize = v1.copy();
@@ -1140,8 +1127,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("Expecting ArithmeticException");
         } catch (ArithmeticException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         RealVector v_projection = v1.projection(v2);
@@ -1164,8 +1149,6 @@ public class SparseRealVectorTest extends TestCase {
             fail("IllegalArgumentException expected");
         } catch (IllegalArgumentException ex) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
 
@@ -1187,7 +1170,7 @@ public class SparseRealVectorTest extends TestCase {
 
         v.setEntry(0, 0);
         assertEquals(v, new OpenMapRealVector(new double[] { 0, 1, 2 }));
-        assertNotSame(v, new OpenMapRealVector(new double[] { 0, 1, 2 + Math.ulp(2)}));
+        assertNotSame(v, new OpenMapRealVector(new double[] { 0, 1, 2 + FastMath.ulp(2)}));
         assertNotSame(v, new OpenMapRealVector(new double[] { 0, 1, 2, 3 }));
 
     }
