@@ -26,13 +26,14 @@ import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.util.Random;
 
-import org.apache.commons.math.ode.ContinuousOutputModel;
 import org.apache.commons.math.ode.DerivativeException;
+import org.apache.commons.math.ode.ContinuousOutputModel;
 import org.apache.commons.math.ode.IntegratorException;
 import org.apache.commons.math.ode.TestProblem1;
 import org.apache.commons.math.ode.TestProblem3;
 import org.apache.commons.math.ode.sampling.StepHandler;
 import org.apache.commons.math.ode.sampling.StepInterpolatorTestUtils;
+import org.apache.commons.math.util.FastMath;
 import org.junit.Test;
 
 public class EulerStepInterpolatorTest {
@@ -50,7 +51,7 @@ public class EulerStepInterpolatorTest {
 
     double[] result = interpolator.getInterpolatedState();
     for (int i = 0; i < result.length; ++i) {
-      assertTrue(Math.abs(result[i] - y[i]) < 1.0e-10);
+      assertTrue(FastMath.abs(result[i] - y[i]) < 1.0e-10);
     }
 
   }
@@ -81,13 +82,13 @@ public class EulerStepInterpolatorTest {
     interpolator.setInterpolatedTime(interpolator.getPreviousTime());
     double[] result = interpolator.getInterpolatedState();
     for (int i = 0; i < result.length; ++i) {
-      assertTrue(Math.abs(result[i] - y0[i]) < 1.0e-10);
+      assertTrue(FastMath.abs(result[i] - y0[i]) < 1.0e-10);
     }
 
     interpolator.setInterpolatedTime(interpolator.getCurrentTime());
     result = interpolator.getInterpolatedState();
     for (int i = 0; i < result.length; ++i) {
-      assertTrue(Math.abs(result[i] - y[i]) < 1.0e-10);
+      assertTrue(FastMath.abs(result[i] - y[i]) < 1.0e-10);
     }
 
   }
@@ -106,15 +107,15 @@ public class EulerStepInterpolatorTest {
 
     interpolator.setInterpolatedTime(0.1);
     double[] result = interpolator.getInterpolatedState();
-    assertTrue(Math.abs(result[0] - 0.1) < 1.0e-10);
-    assertTrue(Math.abs(result[1] - 1.2) < 1.0e-10);
-    assertTrue(Math.abs(result[2] + 2.2) < 1.0e-10);
+    assertTrue(FastMath.abs(result[0] - 0.1) < 1.0e-10);
+    assertTrue(FastMath.abs(result[1] - 1.2) < 1.0e-10);
+    assertTrue(FastMath.abs(result[2] + 2.2) < 1.0e-10);
 
     interpolator.setInterpolatedTime(0.5);
     result = interpolator.getInterpolatedState();
-    assertTrue(Math.abs(result[0] - 0.5) < 1.0e-10);
-    assertTrue(Math.abs(result[1] - 2.0) < 1.0e-10);
-    assertTrue(Math.abs(result[2] + 3.0) < 1.0e-10);
+    assertTrue(FastMath.abs(result[0] - 0.5) < 1.0e-10);
+    assertTrue(FastMath.abs(result[1] - 2.0) < 1.0e-10);
+    assertTrue(FastMath.abs(result[2] + 3.0) < 1.0e-10);
 
   }
 
