@@ -33,6 +33,7 @@ import org.apache.commons.math.ode.events.EventHandler;
 import org.apache.commons.math.ode.nonstiff.GillIntegrator;
 import org.apache.commons.math.ode.sampling.StepHandler;
 import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math.util.FastMath;
 
 public class GillIntegratorTest
   extends TestCase {
@@ -60,12 +61,12 @@ public class GillIntegratorTest
     TestProblemAbstract[] problems = TestProblemFactory.getProblems();
     for (int k = 0; k < problems.length; ++k) {
 
-      double previousError = Double.NaN;
+      double previousValueError = Double.NaN;
+      double previousTimeError = Double.NaN;
       for (int i = 5; i < 10; ++i) {
 
         TestProblemAbstract pb = problems[k].copy();
-        double step = (pb.getFinalTime() - pb.getInitialTime())
-          * Math.pow(2.0, -i);
+        double step = (pb.getFinalTime() - pb.getInitialTime()) * FastMath.pow(2.0, -i);
 
         FirstOrderIntegrator integ = new GillIntegrator(step);
         TestProblemHandler handler = new TestProblemHandler(pb, integ);
@@ -81,12 +82,17 @@ public class GillIntegratorTest
             assertEquals(pb.getFinalTime(), stopTime, 1.0e-10);
         }
 
-        double error = handler.getMaximalValueError();
+        double valueError = handler.getMaximalValueError();
         if (i > 5) {
-          assertTrue(error < Math.abs(previousError));
+          assertTrue(valueError < FastMath.abs(previousValueError));
         }
-        previousError = error;
-        assertEquals(0, handler.getMaximalTimeError(), 1.0e-12);
+        previousValueError = valueError;
+
+        double timeError = handler.getMaximalTimeError();
+        if (i > 5) {
+          assertTrue(timeError <= FastMath.abs(previousTimeError));
+        }
+        previousTimeError = timeError;
 
       }
 
@@ -135,7 +141,7 @@ public class GillIntegratorTest
       throws DerivativeException, IntegratorException {
 
       TestProblem5 pb = new TestProblem5();
-      double step = Math.abs(pb.getFinalTime() - pb.getInitialTime()) * 0.001;
+      double step = FastMath.abs(pb.getFinalTime() - pb.getInitialTime()) * 0.001;
 
       FirstOrderIntegrator integ = new GillIntegrator(step);
       TestProblemHandler handler = new TestProblemHandler(pb, integ);
