@@ -21,6 +21,7 @@ import junit.framework.TestCase;
 
 import org.apache.commons.math.ConvergenceException;
 import org.apache.commons.math.ode.DerivativeException;
+import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.ode.FirstOrderDifferentialEquations;
 import org.apache.commons.math.ode.FirstOrderIntegrator;
 import org.apache.commons.math.ode.IntegratorException;
@@ -31,8 +32,7 @@ import org.apache.commons.math.ode.TestProblem5;
 import org.apache.commons.math.ode.TestProblemHandler;
 import org.apache.commons.math.ode.events.EventException;
 import org.apache.commons.math.ode.events.EventHandler;
-import org.apache.commons.math.ode.sampling.StepHandler;
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math.util.FastMath;
 
 public class HighamHall54IntegratorTest
   extends TestCase {
@@ -41,8 +41,7 @@ public class HighamHall54IntegratorTest
     super(name);
   }
 
-  public void testWrongDerivative() {
-    try {
+  public void testWrongDerivative() throws Exception {
       HighamHall54Integrator integrator =
           new HighamHall54Integrator(0.0, 1.0, 1.0e-10, 1.0e-10);
       FirstOrderDifferentialEquations equations =
@@ -51,7 +50,7 @@ public class HighamHall54IntegratorTest
             public void computeDerivatives(double t, double[] y, double[] dot)
             throws DerivativeException {
             if (t < -0.5) {
-                throw new DerivativeException("{0}", "oops");
+                throw new DerivativeException(LocalizedFormats.SIMPLE_MESSAGE, "oops");
             } else {
                 throw new DerivativeException(new RuntimeException("oops"));
            }
@@ -75,9 +74,6 @@ public class HighamHall54IntegratorTest
         // expected behavior
       }
 
-    } catch (Exception e) {
-      fail("wrong exception caught: " + e.getMessage());
-    }
   }
 
   public void testMinStep() {
@@ -113,7 +109,7 @@ public class HighamHall54IntegratorTest
       TestProblem1 pb = new TestProblem1();
       double minStep = 0;
       double maxStep = pb.getFinalTime() - pb.getInitialTime();
-      double scalAbsoluteTolerance = Math.pow(10.0, i);
+      double scalAbsoluteTolerance = FastMath.pow(10.0, i);
       double scalRelativeTolerance = 0.01 * scalAbsoluteTolerance;
 
       FirstOrderIntegrator integ = new HighamHall54Integrator(minStep, maxStep,
@@ -178,9 +174,10 @@ public class HighamHall54IntegratorTest
     TestProblemHandler handler = new TestProblemHandler(pb, integ);
     integ.addStepHandler(handler);
     EventHandler[] functions = pb.getEventsHandlers();
+    double convergence = 1.0e-8 * maxStep;
     for (int l = 0; l < functions.length; ++l) {
       integ.addEventHandler(functions[l],
-                                 Double.POSITIVE_INFINITY, 1.0e-8 * maxStep, 1000);
+                                 Double.POSITIVE_INFINITY, convergence, 1000);
     }
     assertEquals(functions.length, integ.getEventHandlers().size());
     integ.integrate(pb,
@@ -188,14 +185,14 @@ public class HighamHall54IntegratorTest
                     pb.getFinalTime(), new double[pb.getDimension()]);
 
     assertTrue(handler.getMaximalValueError() < 1.0e-7);
-    assertEquals(0, handler.getMaximalTimeError(), 1.0e-12);
-    assertEquals(12.0, handler.getLastTime(), 1.0e-8 * maxStep);
+    assertEquals(0, handler.getMaximalTimeError(), convergence);
+    assertEquals(12.0, handler.getLastTime(), convergence);
     integ.clearEventHandlers();
     assertEquals(0, integ.getEventHandlers().size());
 
   }
 
-  public void testEventsErrors() {
+  public void testEventsErrors() throws Exception {
 
       final TestProblem1 pb = new TestProblem1();
       double minStep = 0;
@@ -217,7 +214,7 @@ public class HighamHall54IntegratorTest
           double middle = (pb.getInitialTime() + pb.getFinalTime()) / 2;
           double offset = t - middle;
           if (offset > 0) {
-            throw new EventException("Evaluation failed for argument = {0}", t);
+            throw new EventException(LocalizedFormats.EVALUATION_FAILED, t);
           }
           return offset;
         }
@@ -233,13 +230,11 @@ public class HighamHall54IntegratorTest
         fail("an exception should have been thrown");
       } catch (IntegratorException ie) {
         // expected behavior
-      } catch (Exception e) {
-        fail("wrong exception type caught");
       }
 
   }
 
-  public void testEventsNoConvergence() {
+  public void testEventsNoConvergence() throws Exception {
 
     final TestProblem1 pb = new TestProblem1();
     double minStep = 0;
@@ -275,14 +270,11 @@ public class HighamHall54IntegratorTest
     } catch (IntegratorException ie) {
        assertTrue(ie.getCause() != null);
        assertTrue(ie.getCause() instanceof ConvergenceException);
-    } catch (Exception e) {
-      fail("wrong exception type caught");
     }
 
 }
 
-  public void testSanityChecks() {
-    try {
+  public void testSanityChecks() throws Exception {
       final TestProblem3 pb  = new TestProblem3(0.9);
       double minStep = 0;
       double maxStep = pb.getFinalTime() - pb.getInitialTime();
@@ -337,9 +329,6 @@ public class HighamHall54IntegratorTest
         // expected behavior
       }
 
-    } catch (Exception e) {
-      fail("wrong exception caught: " + e.getMessage());
-    }
   }
 
   public void testKepler()
@@ -354,46 +343,13 @@ public class HighamHall54IntegratorTest
     FirstOrderIntegrator integ = new HighamHall54Integrator(minStep, maxStep,
                                                             vecAbsoluteTolerance,
                                                             vecRelativeTolerance);
-    integ.addStepHandler(new KeplerHandler(pb));
+    TestProblemHandler handler = new TestProblemHandler(pb, integ); 
+    integ.addStepHandler(handler);
     integ.integrate(pb,
                     pb.getInitialTime(), pb.getInitialState(),
                     pb.getFinalTime(), new double[pb.getDimension()]);
+    assertEquals(0.0, handler.getMaximalValueError(), 1.5e-4);
     assertEquals("Higham-Hall 5(4)", integ.getName());
   }
 
-  private static class KeplerHandler implements StepHandler {
-    public KeplerHandler(TestProblem3 pb) {
-      this.pb = pb;
-      nbSteps = 0;
-      maxError = 0;
-    }
-    public boolean requiresDenseOutput() {
-      return false;
-    }
-    public void reset() {
-      nbSteps = 0;
-      maxError = 0;
-    }
-    public void handleStep(StepInterpolator interpolator,
-                           boolean isLast) throws DerivativeException {
-
-      ++nbSteps;
-      double[] interpolatedY = interpolator.getInterpolatedState();
-      double[] theoreticalY  = pb.computeTheoreticalState(interpolator.getCurrentTime());
-      double dx = interpolatedY[0] - theoreticalY[0];
-      double dy = interpolatedY[1] - theoreticalY[1];
-      double error = dx * dx + dy * dy;
-      if (error > maxError) {
-        maxError = error;
-      }
-      if (isLast) {
-        assertTrue(maxError < 4.2e-11);
-        assertTrue(nbSteps < 670);
-      }
-    }
-    private TestProblem3 pb;
-    private int nbSteps;
-    private double maxError;
-  }
-
 }
