@@ -27,13 +27,14 @@ import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.util.Random;
 
-import org.apache.commons.math.ode.ContinuousOutputModel;
 import org.apache.commons.math.ode.DerivativeException;
+import org.apache.commons.math.ode.ContinuousOutputModel;
 import org.apache.commons.math.ode.IntegratorException;
 import org.apache.commons.math.ode.TestProblem3;
 import org.apache.commons.math.ode.sampling.StepHandler;
 import org.apache.commons.math.ode.sampling.StepInterpolator;
 import org.apache.commons.math.ode.sampling.StepInterpolatorTestUtils;
+import org.apache.commons.math.util.FastMath;
 import org.junit.Test;
 
 public class HighamHall54StepInterpolatorTest {
@@ -76,8 +77,8 @@ public class HighamHall54StepInterpolatorTest {
         oos.writeObject(handler);
     }
 
-    assertTrue(bos.size () > 158000);
-    assertTrue(bos.size () < 159000);
+    assertTrue(bos.size () > 167000);
+    assertTrue(bos.size () < 168000);
 
     ByteArrayInputStream  bis = new ByteArrayInputStream(bos.toByteArray());
     ObjectInputStream     ois = new ObjectInputStream(bis);
@@ -120,13 +121,13 @@ public class HighamHall54StepInterpolatorTest {
             StepInterpolator cloned = interpolator.copy();
             double tA = cloned.getPreviousTime();
             double tB = cloned.getCurrentTime();
-            double halfStep = Math.abs(tB - tA) / 2;
+            double halfStep = FastMath.abs(tB - tA) / 2;
             assertEquals(interpolator.getPreviousTime(), tA, 1.0e-12);
             assertEquals(interpolator.getCurrentTime(), tB, 1.0e-12);
             for (int i = 0; i < 10; ++i) {
                 double t = (i * tB + (9 - i) * tA) / 9;
                 interpolator.setInterpolatedTime(t);
-                assertTrue(Math.abs(cloned.getInterpolatedTime() - t) > (halfStep / 10));
+                assertTrue(FastMath.abs(cloned.getInterpolatedTime() - t) > (halfStep / 10));
                 cloned.setInterpolatedTime(t);
                 assertEquals(t, cloned.getInterpolatedTime(), 1.0e-12);
                 double[] referenceState = interpolator.getInterpolatedState();
