@@ -32,6 +32,7 @@ import org.apache.commons.math.ode.events.EventHandler;
 import org.apache.commons.math.ode.nonstiff.MidpointIntegrator;
 import org.apache.commons.math.ode.sampling.StepHandler;
 import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math.util.FastMath;
 
 public class MidpointIntegratorTest
   extends TestCase {
@@ -59,12 +60,12 @@ public class MidpointIntegratorTest
     TestProblemAbstract[] problems = TestProblemFactory.getProblems();
     for (int k = 0; k < problems.length; ++k) {
 
-      double previousError = Double.NaN;
+      double previousValueError = Double.NaN;
+      double previousTimeError = Double.NaN;
       for (int i = 4; i < 10; ++i) {
 
         TestProblemAbstract pb = problems[k].copy();
-        double step = (pb.getFinalTime() - pb.getInitialTime())
-          * Math.pow(2.0, -i);
+        double step = (pb.getFinalTime() - pb.getInitialTime()) * FastMath.pow(2.0, -i);
         FirstOrderIntegrator integ = new MidpointIntegrator(step);
         TestProblemHandler handler = new TestProblemHandler(pb, integ);
         integ.addStepHandler(handler);
@@ -80,12 +81,17 @@ public class MidpointIntegratorTest
             assertEquals(pb.getFinalTime(), stopTime, 1.0e-10);
         }
 
-        double error = handler.getMaximalValueError();
+        double valueError = handler.getMaximalValueError();
         if (i > 4) {
-          assertTrue(error < Math.abs(previousError));
+          assertTrue(valueError < FastMath.abs(previousValueError));
         }
-        previousError = error;
-        assertEquals(0, handler.getMaximalTimeError(), 1.0e-12);
+        previousValueError = valueError;
+
+        double timeError = handler.getMaximalTimeError();
+        if (i > 4) {
+          assertTrue(timeError <= FastMath.abs(previousTimeError));
+        }
+        previousTimeError = timeError;
 
       }
 
@@ -136,7 +142,7 @@ public class MidpointIntegratorTest
       throws DerivativeException, IntegratorException {
 
       TestProblem5 pb = new TestProblem5();
-      double step = Math.abs(pb.getFinalTime() - pb.getInitialTime()) * 0.001;
+      double step = FastMath.abs(pb.getFinalTime() - pb.getInitialTime()) * 0.001;
 
       FirstOrderIntegrator integ = new MidpointIntegrator(step);
       TestProblemHandler handler = new TestProblemHandler(pb, integ);
