@@ -23,9 +23,9 @@ import static org.junit.Assert.fail;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.analysis.DifferentiableMultivariateVectorialFunction;
 import org.apache.commons.math.analysis.MultivariateMatrixFunction;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.linear.BlockRealMatrix;
 import org.apache.commons.math.linear.RealMatrix;
 import org.apache.commons.math.optimization.general.GaussNewtonOptimizer;
@@ -159,7 +159,7 @@ public class MultiStartDifferentiableMultivariateVectorialOptimizerTest {
                     return null;
                 }
                 public double[] value(double[] point) throws FunctionEvaluationException {
-                    throw new FunctionEvaluationException(point[0]);
+                    throw new FunctionEvaluationException(point);
                 }
             }, new double[] { 2 }, new double[] { 1 }, new double[] { 0 });
     }
