@@ -30,6 +30,7 @@ import org.apache.commons.math.MaxEvaluationsExceededException;
 import org.apache.commons.math.MaxIterationsExceededException;
 import org.apache.commons.math.analysis.MultivariateRealFunction;
 import org.apache.commons.math.analysis.MultivariateVectorialFunction;
+import org.apache.commons.math.exception.util.LocalizedFormats;
 import org.apache.commons.math.linear.Array2DRowRealMatrix;
 import org.apache.commons.math.linear.RealMatrix;
 import org.apache.commons.math.optimization.GoalType;
@@ -38,18 +39,19 @@ import org.apache.commons.math.optimization.OptimizationException;
 import org.apache.commons.math.optimization.RealPointValuePair;
 import org.apache.commons.math.optimization.SimpleRealPointChecker;
 import org.apache.commons.math.optimization.SimpleScalarValueChecker;
+import org.apache.commons.math.util.FastMath;
 import org.junit.Test;
 
 public class NelderMeadTest {
 
   @Test
-  public void testFunctionEvaluationExceptions() {
+  public void testFunctionEvaluationException() throws OptimizationException, FunctionEvaluationException, IllegalArgumentException {
       MultivariateRealFunction wrong =
           new MultivariateRealFunction() {
             private static final long serialVersionUID = 4751314470965489371L;
             public double value(double[] x) throws FunctionEvaluationException {
                 if (x[0] < 0) {
-                    throw new FunctionEvaluationException(x, "{0}", "oops");
+                    throw new FunctionEvaluationException(x, LocalizedFormats.SIMPLE_MESSAGE, "oops");
                 } else if (x[0] > 1) {
                     throw new FunctionEvaluationException(new RuntimeException("oops"), x);
                 } else {
@@ -64,8 +66,6 @@ public class NelderMeadTest {
       } catch (FunctionEvaluationException ce) {
           // expected behavior
           assertNull(ce.getCause());
-      } catch (Exception e) {
-          fail("wrong exception caught: " + e.getMessage());
       }
       try {
           NelderMead optimizer = new NelderMead(0.9, 1.9, 0.4, 0.6);
@@ -74,8 +74,6 @@ public class NelderMeadTest {
       } catch (FunctionEvaluationException ce) {
           // expected behavior
           assertNotNull(ce.getCause());
-      } catch (Exception e) {
-          fail("wrong exception caught: " + e.getMessage());
       }
   }
 
@@ -97,7 +95,7 @@ public class NelderMeadTest {
           public double value(double[] variables) throws FunctionEvaluationException {
               final double x = variables[0];
               final double y = variables[1];
-              return ((x == 0) || (y == 0)) ? 0 : (Math.atan(x) * Math.atan(x + 2) * Math.atan(y) * Math.atan(y) / (x * y));
+              return ((x == 0) || (y == 0)) ? 0 : (FastMath.atan(x) * FastMath.atan(x + 2) * FastMath.atan(y) * FastMath.atan(y) / (x * y));
           }
       };
 
@@ -297,7 +295,7 @@ public class NelderMeadTest {
           count = 0;
       }
 
-      public double value(double[] x) throws FunctionEvaluationException {
+      public double value(double[] x) {
           ++count;
           double a = x[1] - x[0] * x[0];
           double b = 1.0 - x[0];
@@ -318,7 +316,7 @@ public class NelderMeadTest {
           count = 0;
       }
 
-      public double value(double[] x) throws FunctionEvaluationException {
+      public double value(double[] x) {
           ++count;
           double a = x[0] + 10 * x[1];
           double b = x[2] - x[3];
