@@ -24,15 +24,16 @@ import java.util.Arrays;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.analysis.DifferentiableMultivariateVectorialFunction;
 import org.apache.commons.math.analysis.MultivariateMatrixFunction;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.linear.BlockRealMatrix;
 import org.apache.commons.math.linear.RealMatrix;
 import org.apache.commons.math.optimization.OptimizationException;
 import org.apache.commons.math.optimization.SimpleVectorialPointChecker;
 import org.apache.commons.math.optimization.SimpleVectorialValueChecker;
 import org.apache.commons.math.optimization.VectorialPointValuePair;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * <p>Some of the unit tests are re-implementations of the MINPACK <a
@@ -203,7 +204,7 @@ extends TestCase {
 
     }
 
-    public void testNonInversible() {
+    public void testNonInversible() throws Exception {
 
         LinearProblem problem = new LinearProblem(new double[][] {
                 {  1, 2, -3 },
@@ -218,8 +219,6 @@ extends TestCase {
             fail("an exception should have been caught");
         } catch (OptimizationException ee) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception type caught");
         }
     }
 
@@ -259,7 +258,7 @@ extends TestCase {
 
     }
 
-    public void testMoreEstimatedParametersSimple() {
+    public void testMoreEstimatedParametersSimple() throws Exception {
 
         LinearProblem problem = new LinearProblem(new double[][] {
                 { 3.0, 2.0,  0.0, 0.0 },
@@ -276,13 +275,11 @@ extends TestCase {
             fail("an exception should have been caught");
         } catch (OptimizationException ee) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception type caught");
         }
 
     }
 
-    public void testMoreEstimatedParametersUnsorted() {
+    public void testMoreEstimatedParametersUnsorted() throws Exception {
         LinearProblem problem = new LinearProblem(new double[][] {
                  { 1.0, 1.0,  0.0,  0.0, 0.0,  0.0 },
                  { 0.0, 0.0,  1.0,  1.0, 1.0,  0.0 },
@@ -299,8 +296,6 @@ extends TestCase {
             fail("an exception should have been caught");
         } catch (OptimizationException ee) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception type caught");
         }
     }
 
@@ -358,8 +353,6 @@ extends TestCase {
             fail("an exception should have been thrown");
         } catch (OptimizationException oe) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
         try {
@@ -369,13 +362,11 @@ extends TestCase {
             fail("an exception should have been thrown");
         } catch (FunctionEvaluationException oe) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
 
     }
 
-    public void testMaxIterations() {
+    public void testMaxEvaluations() throws Exception {
         Circle circle = new Circle();
         circle.addPoint( 30.0,  68.0);
         circle.addPoint( 50.0,  -6.0);
@@ -392,8 +383,6 @@ extends TestCase {
             fail("an exception should have been caught");
         } catch (OptimizationException ee) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception type caught");
         }
     }
 
@@ -411,7 +400,7 @@ extends TestCase {
             optimizer.optimize(circle, new double[] { 0, 0, 0, 0, 0 },
                                new double[] { 1, 1, 1, 1, 1 },
                                new double[] { 98.680, 47.345 });
-        assertEquals(1.768262623567235,  Math.sqrt(circle.getN()) * optimizer.getRMS(),  1.0e-10);
+        assertEquals(1.768262623567235,  FastMath.sqrt(circle.getN()) * optimizer.getRMS(),  1.0e-10);
         Point2D.Double center = new Point2D.Double(optimum.getPointRef()[0], optimum.getPointRef()[1]);
         assertEquals(69.96016175359975, circle.getRadius(center), 1.0e-10);
         assertEquals(96.07590209601095, center.x, 1.0e-10);
@@ -466,14 +455,12 @@ extends TestCase {
             fail("an exception should have been caught");
         } catch (OptimizationException ee) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception type caught");
         }
 
         VectorialPointValuePair optimum =
             optimizer.optimize(circle, target, weights, new double[] { 0, 0 });
-        assertEquals(-0.1517383071957963, optimum.getPointRef()[0], 1.0e-8);
-        assertEquals(0.2074999736353867,  optimum.getPointRef()[1], 1.0e-8);
+        assertEquals(-0.1517383071957963, optimum.getPointRef()[0], 1.0e-6);
+        assertEquals(0.2074999736353867,  optimum.getPointRef()[1], 1.0e-6);
         assertEquals(0.04268731682389561, optimizer.getRMS(),       1.0e-8);
 
     }
