@@ -22,11 +22,12 @@ import java.util.Arrays;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.analysis.DifferentiableMultivariateVectorialFunction;
 import org.apache.commons.math.analysis.MultivariateMatrixFunction;
+import org.apache.commons.math.FunctionEvaluationException;
 import org.apache.commons.math.optimization.OptimizationException;
 import org.apache.commons.math.optimization.VectorialPointValuePair;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * <p>Some of the unit tests are re-implementations of the MINPACK <a
@@ -117,11 +118,11 @@ public class MinpackTest extends TestCase {
 
   public void testMinpackRosenbrok() {
     minpackTest(new RosenbrockFunction(new double[] { -1.2, 1.0 },
-                                       Math.sqrt(24.2)), false);
+                                       FastMath.sqrt(24.2)), false);
     minpackTest(new RosenbrockFunction(new double[] { -12.0, 10.0 },
-                                       Math.sqrt(1795769.0)), false);
+                                       FastMath.sqrt(1795769.0)), false);
     minpackTest(new RosenbrockFunction(new double[] { -120.0, 100.0 },
-                                       11.0 * Math.sqrt(169000121.0)), false);
+                                       11.0 * FastMath.sqrt(169000121.0)), false);
   }
 
   public void testMinpackHelicalValley() {
@@ -152,14 +153,14 @@ public class MinpackTest extends TestCase {
     minpackTest(new FreudensteinRothFunction(new double[] { 5.0, -20.0 },
                                              12432.833948863, 6.9988751744895,
                                              new double[] {
-                                               11.4130046614746,
-                                               -0.896796038685958
+                                                11.41300466147456,
+                                                -0.896796038685959
                                              }), false);
     minpackTest(new FreudensteinRothFunction(new double[] { 50.0, -200.0 },
                                              11426454.595762, 6.99887517242903,
                                              new double[] {
-                                               11.4127817857886,
-                                               -0.89680510749204
+                                                 11.412781785788564,
+                                                 -0.8968051074920405
                                              }), false);
   }
 
@@ -325,7 +326,8 @@ public class MinpackTest extends TestCase {
     minpackTest(new JennrichSampsonFunction(10, new double[] { 0.3, 0.4 },
                                             64.5856498144943, 11.1517793413499,
                                             new double[] {
-                                             0.257819926636811, 0.257829976764542
+ //                                            0.2578330049, 0.257829976764542
+                                               0.2578199266368004, 0.25782997676455244
                                             }), false);
   }
 
@@ -489,8 +491,8 @@ public class MinpackTest extends TestCase {
   private void minpackTest(MinpackFunction function, boolean exceptionExpected) {
       LevenbergMarquardtOptimizer optimizer = new LevenbergMarquardtOptimizer();
       optimizer.setMaxIterations(100 * (function.getN() + 1));
-      optimizer.setCostRelativeTolerance(Math.sqrt(2.22044604926e-16));
-      optimizer.setParRelativeTolerance(Math.sqrt(2.22044604926e-16));
+      optimizer.setCostRelativeTolerance(FastMath.sqrt(2.22044604926e-16));
+      optimizer.setParRelativeTolerance(FastMath.sqrt(2.22044604926e-16));
       optimizer.setOrthoTolerance(2.22044604926e-16);
 //      assertTrue(function.checkTheoreticalStartCost(optimizer.getRMS()));
       try {
@@ -499,8 +501,8 @@ public class MinpackTest extends TestCase {
                                  function.getTarget(), function.getWeight(),
                                  function.getStartPoint());
           assertFalse(exceptionExpected);
-          assertTrue(function.checkTheoreticalMinCost(optimizer.getRMS()));
-          assertTrue(function.checkTheoreticalMinParams(optimum));
+          function.checkTheoreticalMinCost(optimizer.getRMS());
+          function.checkTheoreticalMinParams(optimum);
       } catch (OptimizationException lsse) {
           assertTrue(exceptionExpected);
       } catch (FunctionEvaluationException fe) {
@@ -561,23 +563,20 @@ public class MinpackTest extends TestCase {
           return startParams.length;
       }
 
-      public boolean checkTheoreticalMinCost(double rms) {
+      public void checkTheoreticalMinCost(double rms) {
           double threshold = costAccuracy * (1.0 + theoreticalMinCost);
-          return Math.abs(Math.sqrt(m) * rms - theoreticalMinCost) <= threshold;
+          assertEquals(theoreticalMinCost, FastMath.sqrt(m) * rms, threshold);
       }
 
-      public boolean checkTheoreticalMinParams(VectorialPointValuePair optimum) {
+      public void checkTheoreticalMinParams(VectorialPointValuePair optimum) {
           double[] params = optimum.getPointRef();
           if (theoreticalMinParams != null) {
               for (int i = 0; i < theoreticalMinParams.length; ++i) {
                   double mi = theoreticalMinParams[i];
                   double vi = params[i];
-                  if (Math.abs(mi - vi) > (paramsAccuracy * (1.0 + Math.abs(mi)))) {
-                      return false;
-                  }
+                  assertEquals(mi, vi, paramsAccuracy * (1.0 + FastMath.abs(mi)));
               }
           }
-          return true;
       }
 
       public MultivariateMatrixFunction jacobian() {
@@ -679,7 +678,7 @@ public class MinpackTest extends TestCase {
 
     public LinearRank1ZeroColsAndRowsFunction(int m, int n, double x0) {
       super(m, buildArray(n, x0),
-            Math.sqrt((m * (m + 3) - 6) / (2.0 * (2 * m - 3))),
+            FastMath.sqrt((m * (m + 3) - 6) / (2.0 * (2 * m - 3))),
             null);
     }
 
@@ -757,7 +756,7 @@ public class MinpackTest extends TestCase {
       double x2 = variables[1];
       double tmpSquare = x1 * x1 + x2 * x2;
       double tmp1 = twoPi * tmpSquare;
-      double tmp2 = Math.sqrt(tmpSquare);
+      double tmp2 = FastMath.sqrt(tmpSquare);
       return new double[][] {
         {  100 * x2 / tmp1, -100 * x1 / tmp1, 10 },
         { 10 * x1 / tmp2, 10 * x2 / tmp2, 0 },
@@ -774,12 +773,12 @@ public class MinpackTest extends TestCase {
       if (x1 == 0) {
         tmp1 = (x2 >= 0) ? 0.25 : -0.25;
       } else {
-        tmp1 = Math.atan(x2 / x1) / twoPi;
+        tmp1 = FastMath.atan(x2 / x1) / twoPi;
         if (x1 < 0) {
           tmp1 += 0.5;
         }
       }
-      double tmp2 = Math.sqrt(x1 * x1 + x2 * x2);
+      double tmp2 = FastMath.sqrt(x1 * x1 + x2 * x2);
       return new double[] {
         10.0 * (x3 - 10 * tmp1),
         10.0 * (tmp2 - 1),
@@ -787,7 +786,7 @@ public class MinpackTest extends TestCase {
       };
     }
 
-    private static final double twoPi = 2.0 * Math.PI;
+    private static final double twoPi = 2.0 * FastMath.PI;
 
   }
 
@@ -828,8 +827,8 @@ public class MinpackTest extends TestCase {
       };
     }
 
-    private static final double sqrt5  = Math.sqrt( 5.0);
-    private static final double sqrt10 = Math.sqrt(10.0);
+    private static final double sqrt5  = FastMath.sqrt( 5.0);
+    private static final double sqrt10 = FastMath.sqrt(10.0);
 
   }
 
@@ -1000,7 +999,7 @@ public class MinpackTest extends TestCase {
       for (int i = 0; i < m; ++i) {
         double temp = 5.0 * (i + 1) + 45.0 + x3;
         double tmp1 = x2 / temp;
-        double tmp2 = Math.exp(tmp1);
+        double tmp2 = FastMath.exp(tmp1);
         double tmp3 = x1 * tmp2 / temp;
         jacobian[i] = new double[] { tmp2, tmp3, -tmp1 * tmp3 };
       }
@@ -1014,7 +1013,7 @@ public class MinpackTest extends TestCase {
       double x3 = variables[2];
       double[] f = new double[m];
       for (int i = 0; i < m; ++i) {
-        f[i] = x1 * Math.exp(x2 / (5.0 * (i + 1) + 45.0 + x3)) - y[i];
+        f[i] = x1 * FastMath.exp(x2 / (5.0 * (i + 1) + 45.0 + x3)) - y[i];
       }
      return f;
     }
@@ -1122,9 +1121,9 @@ public class MinpackTest extends TestCase {
       for (int i = 0; i < m; ++i) {
         double tmp = (i + 1) / 10.0;
         jacobian[i] = new double[] {
-          -tmp * Math.exp(-tmp * x1),
-           tmp * Math.exp(-tmp * x2),
-          Math.exp(-i - 1) - Math.exp(-tmp)
+          -tmp * FastMath.exp(-tmp * x1),
+           tmp * FastMath.exp(-tmp * x2),
+          FastMath.exp(-i - 1) - FastMath.exp(-tmp)
         };
       }
       return jacobian;
@@ -1138,8 +1137,8 @@ public class MinpackTest extends TestCase {
       double[] f = new double[m];
       for (int i = 0; i < m; ++i) {
         double tmp = (i + 1) / 10.0;
-        f[i] = Math.exp(-tmp * x1) - Math.exp(-tmp * x2)
-             + (Math.exp(-i - 1) - Math.exp(-tmp)) * x3;
+        f[i] = FastMath.exp(-tmp * x1) - FastMath.exp(-tmp * x2)
+             + (FastMath.exp(-i - 1) - FastMath.exp(-tmp)) * x3;
       }
       return f;
     }
@@ -1165,7 +1164,7 @@ public class MinpackTest extends TestCase {
       double[][] jacobian = new double[m][];
       for (int i = 0; i < m; ++i) {
         double t = i + 1;
-        jacobian[i] = new double[] { -t * Math.exp(t * x1), -t * Math.exp(t * x2) };
+        jacobian[i] = new double[] { -t * FastMath.exp(t * x1), -t * FastMath.exp(t * x2) };
       }
       return jacobian;
     }
@@ -1177,7 +1176,7 @@ public class MinpackTest extends TestCase {
       double[] f = new double[m];
       for (int i = 0; i < m; ++i) {
         double temp = i + 1;
-        f[i] = 2 + 2 * temp - Math.exp(temp * x1) - Math.exp(temp * x2);
+        f[i] = 2 + 2 * temp - FastMath.exp(temp * x1) - FastMath.exp(temp * x2);
       }
       return f;
     }
@@ -1206,9 +1205,9 @@ public class MinpackTest extends TestCase {
       double[][] jacobian = new double[m][];
       for (int i = 0; i < m; ++i) {
         double temp = (i + 1) / 5.0;
-        double ti   = Math.sin(temp);
-        double tmp1 = x1 + temp * x2 - Math.exp(temp);
-        double tmp2 = x3 + ti   * x4 - Math.cos(temp);
+        double ti   = FastMath.sin(temp);
+        double tmp1 = x1 + temp * x2 - FastMath.exp(temp);
+        double tmp2 = x3 + ti   * x4 - FastMath.cos(temp);
         jacobian[i] = new double[] {
           2 * tmp1, 2 * temp * tmp1, 2 * tmp2, 2 * ti * tmp2
         };
@@ -1225,8 +1224,8 @@ public class MinpackTest extends TestCase {
       double[] f = new double[m];
       for (int i = 0; i < m; ++i) {
         double temp = (i + 1) / 5.0;
-        double tmp1 = x1 + temp * x2 - Math.exp(temp);
-        double tmp2 = x3 + Math.sin(temp) * x4 - Math.cos(temp);
+        double tmp1 = x1 + temp * x2 - FastMath.exp(temp);
+        double tmp2 = x3 + FastMath.sin(temp) * x4 - FastMath.cos(temp);
         f[i] = tmp1 * tmp1 + tmp2 * tmp2;
       }
       return f;
@@ -1403,8 +1402,8 @@ public class MinpackTest extends TestCase {
       double[][] jacobian = new double[m][];
       for (int i = 0; i < m; ++i) {
         double temp = 10.0 * i;
-        double tmp1 = Math.exp(-temp * x4);
-        double tmp2 = Math.exp(-temp * x5);
+        double tmp1 = FastMath.exp(-temp * x4);
+        double tmp2 = FastMath.exp(-temp * x5);
         jacobian[i] = new double[] {
           -1, -tmp1, -tmp2, temp * x2 * tmp1, temp * x3 * tmp2
         };
@@ -1422,8 +1421,8 @@ public class MinpackTest extends TestCase {
       double[] f = new double[m];
       for (int i = 0; i < m; ++i) {
         double temp = 10.0 * i;
-        double tmp1 = Math.exp(-temp * x4);
-        double tmp2 = Math.exp(-temp * x5);
+        double tmp1 = FastMath.exp(-temp * x4);
+        double tmp2 = FastMath.exp(-temp * x5);
         f[i] = y[i] - (x1 + x2 * tmp1 + x3 * tmp2);
       }
       return f;
@@ -1465,10 +1464,10 @@ public class MinpackTest extends TestCase {
       double[][] jacobian = new double[m][];
       for (int i = 0; i < m; ++i) {
         double temp = i / 10.0;
-        double tmp1 = Math.exp(-x05 * temp);
-        double tmp2 = Math.exp(-x06 * (temp - x09) * (temp - x09));
-        double tmp3 = Math.exp(-x07 * (temp - x10) * (temp - x10));
-        double tmp4 = Math.exp(-x08 * (temp - x11) * (temp - x11));
+        double tmp1 = FastMath.exp(-x05 * temp);
+        double tmp2 = FastMath.exp(-x06 * (temp - x09) * (temp - x09));
+        double tmp3 = FastMath.exp(-x07 * (temp - x10) * (temp - x10));
+        double tmp4 = FastMath.exp(-x08 * (temp - x11) * (temp - x11));
         jacobian[i] = new double[] {
           -tmp1,
           -tmp2,
@@ -1502,10 +1501,10 @@ public class MinpackTest extends TestCase {
       double[] f = new double[m];
       for (int i = 0; i < m; ++i) {
         double temp = i / 10.0;
-        double tmp1 = Math.exp(-x05 * temp);
-        double tmp2 = Math.exp(-x06 * (temp - x09) * (temp - x09));
-        double tmp3 = Math.exp(-x07 * (temp - x10) * (temp - x10));
-        double tmp4 = Math.exp(-x08 * (temp - x11) * (temp - x11));
+        double tmp1 = FastMath.exp(-x05 * temp);
+        double tmp2 = FastMath.exp(-x06 * (temp - x09) * (temp - x09));
+        double tmp3 = FastMath.exp(-x07 * (temp - x10) * (temp - x10));
+        double tmp4 = FastMath.exp(-x08 * (temp - x11) * (temp - x11));
         f[i] = y[i] - (x01 * tmp1 + x02 * tmp2 + x03 * tmp3 + x04 * tmp4);
       }
       return f;
