@@ -30,7 +30,7 @@ import org.apache.commons.math.stat.descriptive.SummaryStatistics;
 /**
  * Test cases for the EmpiricalDistribution class
  *
- * @version $Revision: 924345 $ $Date: 2010-03-17 12:03:56 -0400 (Wed, 17 Mar 2010) $
+ * @version $Revision: 1003907 $ $Date: 2010-10-03 00:23:34 +0200 (dim. 03 oct. 2010) $
  */
 
 public final class EmpiricalDistributionTest extends RetryTestCase {
@@ -135,8 +135,6 @@ public final class EmpiricalDistributionTest extends RetryTestCase {
             fail("Expecting IllegalStateException");
         } catch (IllegalStateException ex) {
             // expected
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
@@ -188,8 +186,6 @@ public final class EmpiricalDistributionTest extends RetryTestCase {
             fail("load((double[]) null) expected NullPointerException");
         } catch (NullPointerException e) {
             // expected
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
@@ -200,8 +196,6 @@ public final class EmpiricalDistributionTest extends RetryTestCase {
             fail("load((URL) null) expected NullPointerException");
         } catch (NullPointerException e) {
             // expected
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
@@ -212,8 +206,6 @@ public final class EmpiricalDistributionTest extends RetryTestCase {
             fail("load((File) null) expected NullPointerException");
         } catch (NullPointerException e) {
             // expected
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
