@@ -24,17 +24,34 @@ import java.util.List;
 import junit.framework.AssertionFailedError;
 
 import org.apache.commons.math.RetryTestCase;
+import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.distribution.BetaDistributionImpl;
+import org.apache.commons.math.distribution.BinomialDistributionImpl;
+import org.apache.commons.math.distribution.BinomialDistributionTest;
+import org.apache.commons.math.distribution.CauchyDistributionImpl;
+import org.apache.commons.math.distribution.ChiSquaredDistributionImpl;
+import org.apache.commons.math.distribution.FDistributionImpl;
+import org.apache.commons.math.distribution.GammaDistributionImpl;
+import org.apache.commons.math.distribution.HypergeometricDistributionImpl;
+import org.apache.commons.math.distribution.HypergeometricDistributionTest;
+import org.apache.commons.math.distribution.PascalDistributionImpl;
+import org.apache.commons.math.distribution.PascalDistributionTest;
 import org.apache.commons.math.distribution.PoissonDistribution;
 import org.apache.commons.math.distribution.PoissonDistributionImpl;
+import org.apache.commons.math.distribution.TDistributionImpl;
+import org.apache.commons.math.distribution.WeibullDistributionImpl;
+import org.apache.commons.math.distribution.ZipfDistributionImpl;
+import org.apache.commons.math.distribution.ZipfDistributionTest;
 import org.apache.commons.math.stat.Frequency;
 import org.apache.commons.math.stat.descriptive.SummaryStatistics;
 import org.apache.commons.math.stat.inference.ChiSquareTest;
 import org.apache.commons.math.stat.inference.ChiSquareTestImpl;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Test cases for the RandomData class.
  *
- * @version $Revision: 924362 $ $Date: 2009-04-05 11:55:59 -0500 (Sun, 05 Apr
+ * @version $Revision: 1042376 $ $Date: 2009-04-05 11:55:59 -0500 (Sun, 05 Apr
  *          2009) $
  */
 
@@ -45,13 +62,13 @@ public class RandomDataTest extends RetryTestCase {
         randomData = new RandomDataImpl();
     }
 
-    protected long smallSampleSize = 1000;
-    protected double[] expected = { 250, 250, 250, 250 };
-    protected int largeSampleSize = 10000;
-    private String[] hex = { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
+    protected final long smallSampleSize = 1000;
+    protected final double[] expected = { 250, 250, 250, 250 };
+    protected final int largeSampleSize = 10000;
+    private final String[] hex = { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
             "a", "b", "c", "d", "e", "f" };
     protected RandomDataImpl randomData = null;
-    protected ChiSquareTestImpl testStatistic = new ChiSquareTestImpl();
+    protected final ChiSquareTestImpl testStatistic = new ChiSquareTestImpl();
 
     public void testNextIntExtremeValues() {
         int x = randomData.nextInt(Integer.MIN_VALUE, Integer.MAX_VALUE);
@@ -179,7 +196,7 @@ public class RandomDataTest extends RetryTestCase {
 
     /**
      * Make sure that empirical distribution of random Poisson(4)'s has P(X <=
-     * 5) close to actual cumulative Poisson probablity and that nextPoisson
+     * 5) close to actual cumulative Poisson probability and that nextPoisson
      * fails when mean is non-positive TODO: replace with statistical test,
      * adding test stat to TestStatistic
      */
@@ -192,11 +209,7 @@ public class RandomDataTest extends RetryTestCase {
         }
         Frequency f = new Frequency();
         for (int i = 0; i < largeSampleSize; i++) {
-            try {
-                f.addValue(randomData.nextPoisson(4.0d));
-            } catch (Exception ex) {
-                fail(ex.getMessage());
-            }
+            f.addValue(randomData.nextPoisson(4.0d));
         }
         long cumFreq = f.getCount(0) + f.getCount(1) + f.getCount(2)
                 + f.getCount(3) + f.getCount(4) + f.getCount(5);
@@ -220,12 +233,15 @@ public class RandomDataTest extends RetryTestCase {
     }
 
     public void testNextPoissonConsistency() throws Exception {
+        
+        // Reseed randomGenerator to get fixed sequence
+        randomData.reSeed(1000);  
+        
         // Small integral means
         for (int i = 1; i < 100; i++) {
             checkNextPoissonConsistency(i);
         }
         // non-integer means
-        RandomData randomData = new RandomDataImpl();
         for (int i = 1; i < 10; i++) {
             checkNextPoissonConsistency(randomData.nextUniform(1, 1000));
         }
@@ -243,14 +259,14 @@ public class RandomDataTest extends RetryTestCase {
      * to the corresponding expected distribution computed using PoissonDistributionImpl.
      * Uses ChiSquare test of goodness of fit to evaluate the null hypothesis that the
      * distributions are the same. If the null hypothesis can be rejected with confidence
-     * 1 - alpha, the check fails.  This check will fail randomly with probability alpha.
+     * 1 - alpha, the check fails.
      */
     public void checkNextPoissonConsistency(double mean) throws Exception {
         // Generate sample values
-        int sampleSize = 1000;        // Number of deviates to generate
-        int minExpectedCount = 7;     // Minimum size of expected bin count
+        final int sampleSize = 1000;        // Number of deviates to generate
+        final int minExpectedCount = 7;     // Minimum size of expected bin count
         long maxObservedValue = 0;
-        double alpha = 0.001;         // Probability of false failure
+        final double alpha = 0.001;         // Probability of false failure
         Frequency frequency = new Frequency();
         for (int i = 0; i < sampleSize; i++) {
             long value = randomData.nextPoisson(mean);
@@ -284,7 +300,7 @@ public class RandomDataTest extends RetryTestCase {
         while (!widthSufficient) {
             lowerBinMass = poissonDistribution.cumulativeProbability(lower, lower + binWidth - 1);
             upperBinMass = poissonDistribution.cumulativeProbability(upper - binWidth + 1, upper);
-            widthSufficient = Math.min(lowerBinMass, upperBinMass) * sampleSize >= minExpectedCount;
+            widthSufficient = FastMath.min(lowerBinMass, upperBinMass) * sampleSize >= minExpectedCount;
             binWidth++;
         }
 
@@ -339,7 +355,7 @@ public class RandomDataTest extends RetryTestCase {
             // Fail if we can reject null hypothesis that distributions are the same
             assertFalse(chiSquareTest.chiSquareTest(expected, observed, alpha));
         } catch (AssertionFailedError ex) {
-            StringBuffer msgBuffer = new StringBuffer();
+            StringBuilder msgBuffer = new StringBuilder();
             DecimalFormat df = new DecimalFormat("#.##");
             msgBuffer.append("Chisquare test failed for mean = ");
             msgBuffer.append(mean);
@@ -368,7 +384,7 @@ public class RandomDataTest extends RetryTestCase {
         }
     }
 
-    /** test dispersion and failute modes for nextHex() */
+    /** test dispersion and failure modes for nextHex() */
     public void testNextHex() {
         try {
             randomData.nextHexString(-1);
@@ -423,7 +439,7 @@ public class RandomDataTest extends RetryTestCase {
                 testStatistic.chiSquare(expected, observed) < 37.70);
     }
 
-    /** test dispersion and failute modes for nextHex() */
+    /** test dispersion and failure modes for nextHex() */
     public void testNextSecureHex() {
         try {
             randomData.nextSecureHexString(-1);
@@ -544,7 +560,7 @@ public class RandomDataTest extends RetryTestCase {
          * t-test at .001-level TODO: replace with externalized t-test, with
          * test statistic defined in TestStatistic
          */
-        assertTrue(Math.abs(xbar) / (s / Math.sqrt(n)) < 3.29);
+        assertTrue(FastMath.abs(xbar) / (s / FastMath.sqrt(n)) < 3.29);
     }
 
     /** test failure modes and distribution of nextExponential() */
@@ -774,4 +790,201 @@ public class RandomDataTest extends RetryTestCase {
         fail("permutation not found");
         return -1;
     }
+    
+    public void testNextInversionDeviate() throws Exception {
+        // Set the seed for the default random generator
+        randomData.reSeed(100);
+        double[] quantiles = new double[10];
+        for (int i = 0; i < 10; i++) {
+            quantiles[i] = randomData.nextUniform(0, 1);
+        }
+        // Reseed again so the inversion generator gets the same sequence
+        randomData.reSeed(100);
+        BetaDistributionImpl betaDistribution = new BetaDistributionImpl(2, 4);
+        /*
+         *  Generate a sequence of deviates using inversion - the distribution function
+         *  evaluated at the random value from the distribution should match the uniform
+         *  random value used to generate it, which is stored in the quantiles[] array.
+         */
+        for (int i = 0; i < 10; i++) {
+            double value = randomData.nextInversionDeviate(betaDistribution);
+            assertEquals(betaDistribution.cumulativeProbability(value), quantiles[i], 10E-9);
+        } 
+    }
+    
+    public void testNextBeta() throws Exception {
+        double[] quartiles = TestUtils.getDistributionQuartiles(new BetaDistributionImpl(2,5));
+        long[] counts = new long[4];
+        randomData.reSeed(1000);
+        for (int i = 0; i < 1000; i++) {
+            double value = randomData.nextBeta(2, 5);
+            TestUtils.updateCounts(value, counts, quartiles);
+        }
+        TestUtils.assertChiSquareAccept(expected, counts, 0.001);
+    }
+    
+    public void testNextCauchy() throws Exception {
+        double[] quartiles = TestUtils.getDistributionQuartiles(new CauchyDistributionImpl(1.2, 2.1));
+        long[] counts = new long[4];
+        randomData.reSeed(1000);
+        for (int i = 0; i < 1000; i++) {
+            double value = randomData.nextCauchy(1.2, 2.1);
+            TestUtils.updateCounts(value, counts, quartiles);
+        }
+        TestUtils.assertChiSquareAccept(expected, counts, 0.001);
+    }
+    
+    public void testNextChiSquare() throws Exception {
+        double[] quartiles = TestUtils.getDistributionQuartiles(new ChiSquaredDistributionImpl(12));
+        long[] counts = new long[4];
+        randomData.reSeed(1000);
+        for (int i = 0; i < 1000; i++) {
+            double value = randomData.nextChiSquare(12);
+            TestUtils.updateCounts(value, counts, quartiles);
+        }
+        TestUtils.assertChiSquareAccept(expected, counts, 0.001);
+    }
+    
+    public void testNextF() throws Exception {
+        double[] quartiles = TestUtils.getDistributionQuartiles(new FDistributionImpl(12, 5));
+        long[] counts = new long[4];
+        randomData.reSeed(1000);
+        for (int i = 0; i < 1000; i++) {
+            double value = randomData.nextF(12, 5);
+            TestUtils.updateCounts(value, counts, quartiles);
+        }
+        TestUtils.assertChiSquareAccept(expected, counts, 0.001);
+    }
+    
+    public void testNextGamma() throws Exception {
+        double[] quartiles = TestUtils.getDistributionQuartiles(new GammaDistributionImpl(4, 2));
+        long[] counts = new long[4];
+        randomData.reSeed(1000);
+        for (int i = 0; i < 1000; i++) {
+            double value = randomData.nextGamma(4, 2);
+            TestUtils.updateCounts(value, counts, quartiles);
+        }
+        TestUtils.assertChiSquareAccept(expected, counts, 0.001);
+    }
+    
+    public void testNextT() throws Exception {
+        double[] quartiles = TestUtils.getDistributionQuartiles(new TDistributionImpl(10));
+        long[] counts = new long[4];
+        randomData.reSeed(1000);
+        for (int i = 0; i < 1000; i++) {
+            double value = randomData.nextT(10);
+            TestUtils.updateCounts(value, counts, quartiles);
+        }
+        TestUtils.assertChiSquareAccept(expected, counts, 0.001);
+    }
+    
+    public void testNextWeibull() throws Exception {
+        double[] quartiles = TestUtils.getDistributionQuartiles(new WeibullDistributionImpl(1.2, 2.1));
+        long[] counts = new long[4];
+        randomData.reSeed(1000);
+        for (int i = 0; i < 1000; i++) {
+            double value = randomData.nextWeibull(1.2, 2.1);
+            TestUtils.updateCounts(value, counts, quartiles);
+        }
+        TestUtils.assertChiSquareAccept(expected, counts, 0.001);
+    }
+    
+    public void testNextBinomial() throws Exception {
+        BinomialDistributionTest testInstance = new BinomialDistributionTest("");
+        int[] densityPoints = testInstance.makeDensityTestPoints();
+        double[] densityValues = testInstance.makeDensityTestValues();
+        int sampleSize = 1000;
+        int length = TestUtils.eliminateZeroMassPoints(densityPoints, densityValues);
+        BinomialDistributionImpl distribution = (BinomialDistributionImpl) testInstance.makeDistribution();
+        double[] expectedCounts = new double[length];
+        long[] observedCounts = new long[length];
+        for (int i = 0; i < length; i++) {
+            expectedCounts[i] = sampleSize * densityValues[i];
+        }
+        randomData.reSeed(1000);
+        for (int i = 0; i < sampleSize; i++) {
+          int value = randomData.nextBinomial(distribution.getNumberOfTrials(),
+                  distribution.getProbabilityOfSuccess());
+          for (int j = 0; j < length; j++) {
+              if (value == densityPoints[j]) {
+                  observedCounts[j]++;
+              }
+          }
+        }
+        TestUtils.assertChiSquareAccept(densityPoints, expectedCounts, observedCounts, .001);
+    }
+    
+    public void testNextHypergeometric() throws Exception {
+        HypergeometricDistributionTest testInstance = new HypergeometricDistributionTest("");
+        int[] densityPoints = testInstance.makeDensityTestPoints();
+        double[] densityValues = testInstance.makeDensityTestValues();
+        int sampleSize = 1000;
+        int length = TestUtils.eliminateZeroMassPoints(densityPoints, densityValues);
+        HypergeometricDistributionImpl distribution = (HypergeometricDistributionImpl) testInstance.makeDistribution();
+        double[] expectedCounts = new double[length];
+        long[] observedCounts = new long[length];
+        for (int i = 0; i < length; i++) {
+            expectedCounts[i] = sampleSize * densityValues[i];
+        }
+        randomData.reSeed(1000);
+        for (int i = 0; i < sampleSize; i++) {
+          int value = randomData.nextHypergeometric(distribution.getPopulationSize(),
+                  distribution.getNumberOfSuccesses(), distribution.getSampleSize());
+          for (int j = 0; j < length; j++) {
+              if (value == densityPoints[j]) {
+                  observedCounts[j]++;
+              }
+          }
+        }
+        TestUtils.assertChiSquareAccept(densityPoints, expectedCounts, observedCounts, .001);
+    }
+    
+    public void testNextPascal() throws Exception {
+        PascalDistributionTest testInstance = new PascalDistributionTest("");
+        int[] densityPoints = testInstance.makeDensityTestPoints();
+        double[] densityValues = testInstance.makeDensityTestValues();
+        int sampleSize = 1000;
+        int length = TestUtils.eliminateZeroMassPoints(densityPoints, densityValues);
+        PascalDistributionImpl distribution = (PascalDistributionImpl) testInstance.makeDistribution();
+        double[] expectedCounts = new double[length];
+        long[] observedCounts = new long[length];
+        for (int i = 0; i < length; i++) {
+            expectedCounts[i] = sampleSize * densityValues[i];
+        }
+        randomData.reSeed(1000);
+        for (int i = 0; i < sampleSize; i++) {
+          int value = randomData.nextPascal(distribution.getNumberOfSuccesses(), distribution.getProbabilityOfSuccess());
+          for (int j = 0; j < length; j++) {
+              if (value == densityPoints[j]) {
+                  observedCounts[j]++;
+              }
+          }
+        }
+        TestUtils.assertChiSquareAccept(densityPoints, expectedCounts, observedCounts, .001);
+    }
+    
+    public void testNextZipf() throws Exception {
+        ZipfDistributionTest testInstance = new ZipfDistributionTest("");
+        int[] densityPoints = testInstance.makeDensityTestPoints();
+        double[] densityValues = testInstance.makeDensityTestValues();
+        int sampleSize = 1000;
+        int length = TestUtils.eliminateZeroMassPoints(densityPoints, densityValues);
+        ZipfDistributionImpl distribution = (ZipfDistributionImpl) testInstance.makeDistribution();
+        double[] expectedCounts = new double[length];
+        long[] observedCounts = new long[length];
+        for (int i = 0; i < length; i++) {
+            expectedCounts[i] = sampleSize * densityValues[i];
+        }
+        randomData.reSeed(1000);
+        for (int i = 0; i < sampleSize; i++) {
+          int value = randomData.nextZipf(distribution.getNumberOfElements(), distribution.getExponent());
+          for (int j = 0; j < length; j++) {
+              if (value == densityPoints[j]) {
+                  observedCounts[j]++;
+              }
+          }
+        }
+        TestUtils.assertChiSquareAccept(densityPoints, expectedCounts, observedCounts, .001);
+    }
+    
 }
