@@ -25,7 +25,7 @@ import org.apache.commons.math.stat.descriptive.SummaryStatistics;
 /**
  * Test cases for the ValueServer class.
  *
- * @version $Revision: 902201 $ $Date: 2010-01-22 13:18:16 -0500 (Fri, 22 Jan 2010) $
+ * @version $Revision: 1003907 $ $Date: 2010-10-03 00:23:34 +0200 (dim. 03 oct. 2010) $
  */
 
 public final class ValueServerTest extends RetryTestCase {
@@ -39,12 +39,8 @@ public final class ValueServerTest extends RetryTestCase {
     @Override
     public void setUp() {
         vs.setMode(ValueServer.DIGEST_MODE);
-        try {
-            URL url = getClass().getResource("testData.txt");
-            vs.setValuesFileURL(url);
-        } catch (Exception ex) {
-            fail("malformed test URL");
-        }
+        URL url = getClass().getResource("testData.txt");
+        vs.setValuesFileURL(url);
     }
 
     /**
@@ -92,7 +88,7 @@ public final class ValueServerTest extends RetryTestCase {
         } catch (IllegalStateException ex) {}
     }
 
-    public void testEmptyReplayFile() {
+    public void testEmptyReplayFile() throws Exception {
         try {
             URL url = getClass().getResource("emptyFile.txt");
             vs.setMode(ValueServer.REPLAY_MODE);
@@ -101,12 +97,10 @@ public final class ValueServerTest extends RetryTestCase {
             fail("an exception should have been thrown");
         } catch (EOFException eof) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
-    public void testEmptyDigestFile() {
+    public void testEmptyDigestFile() throws Exception {
         try {
             URL url = getClass().getResource("emptyFile.txt");
             vs.setMode(ValueServer.DIGEST_MODE);
@@ -115,8 +109,6 @@ public final class ValueServerTest extends RetryTestCase {
             fail("an exception should have been thrown");
         } catch (EOFException eof) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
