@@ -18,11 +18,12 @@ package org.apache.commons.math.special;
 
 import org.apache.commons.math.MathException;
 import org.apache.commons.math.TestUtils;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
 /**
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public class GammaTest extends TestCase {
 
@@ -115,7 +116,7 @@ public class GammaTest extends TestCase {
                 -1e+17, -1e+18, -1e+19, -1e+20, -1e+21, -1e+22, -1e+23, -1e+24, -1e+25, -1e+26,
                 -1e+27, -1e+28, -1e+29, -1e+30};
         for (double n = 1; n < 30; n++) {
-            checkRelativeError(String.format("Test %.0f: ", n), expected[(int) (n - 1)], Gamma.digamma(Math.pow(10.0, -n)), 1e-8);
+            checkRelativeError(String.format("Test %.0f: ", n), expected[(int) (n - 1)], Gamma.digamma(FastMath.pow(10.0, -n)), 1e-8);
         }
     }
 
@@ -145,6 +146,6 @@ public class GammaTest extends TestCase {
     }
 
     private void checkRelativeError(String msg, double expected, double actual, double tolerance) {
-        assertEquals(msg, expected, actual, Math.abs(tolerance * actual));
+        assertEquals(msg, expected, actual, FastMath.abs(tolerance * actual));
     }
 }
