@@ -28,7 +28,7 @@ import org.apache.commons.math.TestUtils;
 /**
  * Test cases for the {@link Frequency} class.
  *
- * @version $Revision: 902215 $ $Date: 2010-01-22 13:40:55 -0500 (Fri, 22 Jan 2010) $
+ * @version $Revision: 1044981 $ $Date: 2010-12-13 01:43:57 +0100 (lun. 13 déc. 2010) $
  */
 
 public final class FrequencyTest extends TestCase {
@@ -273,5 +273,15 @@ public final class FrequencyTest extends TestCase {
         f.addValue(twoI);
         assertEquals(f, TestUtils.serializeAndRecover(f));
     }
+    
+    public void testGetUniqueCount() {
+        assertEquals(0, f.getUniqueCount());
+        f.addValue(oneL);
+        assertEquals(1, f.getUniqueCount());
+        f.addValue(oneL);
+        assertEquals(1, f.getUniqueCount());
+        f.addValue(twoI);
+        assertEquals(2, f.getUniqueCount());
+    }
 }
 
