@@ -21,6 +21,7 @@ import org.apache.commons.math.distribution.TDistribution;
 import org.apache.commons.math.distribution.TDistributionImpl;
 import org.apache.commons.math.linear.RealMatrix;
 import org.apache.commons.math.linear.BlockRealMatrix;
+import org.apache.commons.math.util.FastMath;
 
 import junit.framework.TestCase;
 
@@ -160,6 +161,27 @@ public class PearsonsCorrelationTest extends TestCase {
          fillUpper(rPMatrix, 0d);
          TestUtils.assertEquals("correlation p values", rPMatrix, corrInstance.getCorrelationPValues(), 10E-15);
     }
+    
+    /**
+     * Test p-value near 0. JIRA: MATH-371
+     */
+    public void testPValueNearZero() throws Exception {
+        /*
+         * Create a dataset that has r -> 1, p -> 0 as dimension increases.
+         * Prior to the fix for MATH-371, p vanished for dimension >= 14.
+         * Post fix, p-values diminish smoothly, vanishing at dimension = 127.
+         * Tested value is ~1E-303.
+         */
+        int dimension = 120; 
+        double[][] data = new double[dimension][2];
+        for (int i = 0; i < dimension; i++) {
+            data[i][0] = i;
+            data[i][1] = i + 1/((double)i + 1);
+        }
+        PearsonsCorrelation corrInstance = new PearsonsCorrelation(data);
+        assertTrue(corrInstance.getCorrelationPValues().getEntry(0, 1) > 0);
+    }
+    
 
     /**
      * Constant column
@@ -206,7 +228,7 @@ public class PearsonsCorrelationTest extends TestCase {
         RealMatrix stdErrors = corrInstance.getCorrelationStandardErrors();
         for (int i = 0; i < 5; i++) {
             for (int j = 0; j < i; j++) {
-                double t = Math.abs(rValues.getEntry(i, j)) / stdErrors.getEntry(i, j);
+                double t = FastMath.abs(rValues.getEntry(i, j)) / stdErrors.getEntry(i, j);
                 double p = 2 * (1 - tDistribution.cumulativeProbability(t));
                 assertEquals(p, pValues.getEntry(i, j), 10E-15);
             }
