@@ -23,7 +23,7 @@ import org.apache.commons.math.util.MathUtils;
 /**
  * Test cases for the DescriptiveStatistics class.
  *
- * @version $Revision: 902201 $ $Date: 2007-08-16 15:36:33 -0500 (Thu, 16 Aug
+ * @version $Revision: 1003907 $ $Date: 2007-08-16 15:36:33 -0500 (Thu, 16 Aug
  *          2007) $
  */
 public class DescriptiveStatisticsTest extends TestCase {
@@ -72,8 +72,6 @@ public class DescriptiveStatisticsTest extends TestCase {
             fail("an exception should have been thrown");
         } catch (IllegalArgumentException iae) {
             // expected
-        } catch (Exception e) {
-            fail("wrong exception caught: " + e.getMessage());
         }
         assertEquals(300, stats.getWindowSize());
         stats.setWindowSize(50);
@@ -210,11 +208,11 @@ public class DescriptiveStatisticsTest extends TestCase {
             dstat.addValue(i);
         }
 
-        assertTrue(MathUtils.equals(mean1, dstat.getMean()));
+        assertTrue(MathUtils.equalsIncludingNaN(mean1, dstat.getMean()));
         dstat.replaceMostRecentValue(0);
-        assertTrue(MathUtils.equals(mean2, dstat.getMean()));
+        assertTrue(MathUtils.equalsIncludingNaN(mean2, dstat.getMean()));
         dstat.removeMostRecentValue();
-        assertTrue(MathUtils.equals(mean3, dstat.getMean()));
+        assertTrue(MathUtils.equalsIncludingNaN(mean3, dstat.getMean()));
 
     }
 
