@@ -24,10 +24,11 @@ import org.apache.commons.math.MathException;
 import org.apache.commons.math.stat.descriptive.UnivariateStatistic;
 import org.apache.commons.math.stat.descriptive.DescriptiveStatistics;
 import org.apache.commons.math.util.DefaultTransformer;
+import org.apache.commons.math.util.FastMath;
 import org.apache.commons.math.util.NumberTransformer;
 
 /**
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public class ListUnivariateImpl extends DescriptiveStatistics implements Serializable {
 
@@ -83,7 +84,7 @@ public class ListUnivariateImpl extends DescriptiveStatistics implements Seriali
         if (windowSize != DescriptiveStatistics.INFINITE_WINDOW &&
             windowSize < list.size())
         {
-            length = list.size() - Math.max(0, list.size() - windowSize);
+            length = list.size() - FastMath.max(0, list.size() - windowSize);
         }
 
         // Create an array to hold all values
