@@ -24,11 +24,12 @@ import junit.framework.TestCase;
 import org.apache.commons.math.DimensionMismatchException;
 import org.apache.commons.math.TestUtils;
 import org.apache.commons.math.stat.descriptive.moment.Mean;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Test cases for the {@link MultivariateSummaryStatistics} class.
  *
- * @version $Revision: 902201 $ $Date: 2010-01-22 13:18:16 -0500 (Fri, 22 Jan 2010) $
+ * @version $Revision: 1003907 $ $Date: 2010-10-03 00:23:34 +0200 (dim. 03 oct. 2010) $
  */
 
 public class MultivariateSummaryStatisticsTest extends TestCase {
@@ -87,16 +88,17 @@ public class MultivariateSummaryStatisticsTest extends TestCase {
         stats.addValue(new double[] {3, 1});
         Locale d = Locale.getDefault();
         Locale.setDefault(Locale.US);
-        assertEquals("MultivariateSummaryStatistics:\n" +
-                     "n: 3\n" +
-                     "min: 1.0, 1.0\n" +
-                     "max: 3.0, 3.0\n" +
-                     "mean: 2.0, 2.0\n" +
-                     "geometric mean: 1.817..., 1.817...\n" +
-                     "sum of squares: 14.0, 14.0\n" +
-                     "sum of logarithms: 1.791..., 1.791...\n" +
-                     "standard deviation: 1.0, 1.0\n" +
-                     "covariance: Array2DRowRealMatrix{{1.0,-1.0},{-1.0,1.0}}\n",
+        final String suffix = System.getProperty("line.separator");
+        assertEquals("MultivariateSummaryStatistics:" + suffix+
+                     "n: 3" +suffix+
+                     "min: 1.0, 1.0" +suffix+
+                     "max: 3.0, 3.0" +suffix+
+                     "mean: 2.0, 2.0" +suffix+
+                     "geometric mean: 1.817..., 1.817..." +suffix+
+                     "sum of squares: 14.0, 14.0" +suffix+
+                     "sum of logarithms: 1.791..., 1.791..." +suffix+
+                     "standard deviation: 1.0, 1.0" +suffix+
+                     "covariance: Array2DRowRealMatrix{{1.0,-1.0},{-1.0,1.0}}" +suffix,
                      stats.toString().replaceAll("([0-9]+\\.[0-9][0-9][0-9])[0-9]+", "$1..."));
         Locale.setDefault(d);
     }
@@ -171,10 +173,9 @@ public class MultivariateSummaryStatisticsTest extends TestCase {
     public void testDimension() {
         try {
             createMultivariateSummaryStatistics(2, true).addValue(new double[3]);
+            fail("Expecting DimensionMismatchException");
         } catch (DimensionMismatchException dme) {
             // expected behavior
-        } catch (Exception e) {
-            fail("wrong exception caught");
         }
     }
 
@@ -201,8 +202,8 @@ public class MultivariateSummaryStatisticsTest extends TestCase {
         assertEquals( 2.9129506302439405217, u.getGeometricMean()[1], 1.0e-10);
         assertEquals( 2, u.getMean()[0], 1.0e-10);
         assertEquals( 3, u.getMean()[1], 1.0e-10);
-        assertEquals(Math.sqrt(2.0 / 3.0), u.getStandardDeviation()[0], 1.0e-10);
-        assertEquals(Math.sqrt(2.0 / 3.0), u.getStandardDeviation()[1], 1.0e-10);
+        assertEquals(FastMath.sqrt(2.0 / 3.0), u.getStandardDeviation()[0], 1.0e-10);
+        assertEquals(FastMath.sqrt(2.0 / 3.0), u.getStandardDeviation()[1], 1.0e-10);
         assertEquals(2.0 / 3.0, u.getCovariance().getEntry(0, 0), 1.0e-10);
         assertEquals(2.0 / 3.0, u.getCovariance().getEntry(0, 1), 1.0e-10);
         assertEquals(2.0 / 3.0, u.getCovariance().getEntry(1, 0), 1.0e-10);
