@@ -17,13 +17,15 @@
 package org.apache.commons.math.stat.descriptive;
 
 
+import java.util.Locale;
+
 import junit.framework.TestCase;
 
 import org.apache.commons.math.TestUtils;
 /**
  * Test cases for the {@link StatisticalSummaryValues} class.
  *
- * @version $Revision: 902201 $ $Date: 2010-01-22 13:18:16 -0500 (Fri, 22 Jan 2010) $
+ * @version $Revision: 1038873 $ $Date: 2010-11-25 00:35:13 +0100 (jeu. 25 nov. 2010) $
  */
 
 public final class StatisticalSummaryValuesTest extends TestCase {
@@ -65,4 +67,19 @@ public final class StatisticalSummaryValuesTest extends TestCase {
         TestUtils.assertEquals("min",s.getMin(),u.getMin(), 0);
         TestUtils.assertEquals("max",s.getMax(),u.getMax(), 0);
     }
+    
+    public void testToString() {
+        StatisticalSummaryValues u  = new StatisticalSummaryValues(4.5, 16, 10, 5, 4, 45);
+        Locale d = Locale.getDefault();
+        Locale.setDefault(Locale.US);
+        assertEquals("StatisticalSummaryValues:\n" +
+                     "n: 10\n" +
+                     "min: 4.0\n" +
+                     "max: 5.0\n" +
+                     "mean: 4.5\n" +
+                     "std dev: 4.0\n" +
+                     "variance: 16.0\n" +
+                     "sum: 45.0\n",  u.toString());
+        Locale.setDefault(d);
+    }
 }
