@@ -18,10 +18,11 @@ package org.apache.commons.math.stat.descriptive;
 
 import org.apache.commons.math.TestUtils;
 import org.apache.commons.math.stat.descriptive.moment.SecondMoment;
+import org.apache.commons.math.util.FastMath;
 
 /**
  * Test cases for {@link StorelessUnivariateStatistic} classes.
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 990655 $ $Date: 2010-08-29 23:49:40 +0200 (dim. 29 août 2010) $
  */
 public abstract class StorelessUnivariateStatisticAbstractTest
     extends UnivariateStatisticAbstractTest {
@@ -183,7 +184,7 @@ public abstract class StorelessUnivariateStatisticAbstractTest
         StorelessUnivariateStatistic replica = null;
 
         // Randomly select a portion of testArray to load first
-        long index = Math.round((Math.random()) * testArray.length);
+        long index = FastMath.round((FastMath.random()) * testArray.length);
 
         // Put first half in master and copy master to replica
         master.incrementAll(testArray, 0, (int) index);
