@@ -13,12 +13,10 @@
  */
 package org.apache.commons.math.stat.descriptive;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
 
 /**
  * Test cases for the {@link SynchronizedMultivariateSummaryStatisticsTest} class.
- * @version $Revision: 800112 $ $Date: 2007-08-16 15:36:33 -0500 (Thu, 16 Aug
+ * @version $Revision: 902201 $ $Date: 2007-08-16 15:36:33 -0500 (Thu, 16 Aug
  *          2007) $
  */
 public final class SynchronizedMultivariateSummaryStatisticsTest extends MultivariateSummaryStatisticsTest {
@@ -27,12 +25,6 @@ public final class SynchronizedMultivariateSummaryStatisticsTest extends Multiva
         super(name);
     }
 
-    public static Test suite() {
-        TestSuite suite = new TestSuite(SynchronizedMultivariateSummaryStatisticsTest.class);
-        suite.setName("SynchronizedMultivariateSummaryStatistics Tests");
-        return suite;
-    }
-
     @Override
     protected MultivariateSummaryStatistics createMultivariateSummaryStatistics(int k, boolean isCovarianceBiasCorrected) {
         return new SynchronizedMultivariateSummaryStatistics(k, isCovarianceBiasCorrected);
