@@ -17,7 +17,7 @@
 package org.apache.commons.math.transform;
 
 import org.apache.commons.math.analysis.*;
-import org.apache.commons.math.MathException;
+import org.apache.commons.math.util.FastMath;
 import junit.framework.TestCase;
 
 /**
@@ -26,7 +26,7 @@ import junit.framework.TestCase;
  * FST algorithm is exact, the small tolerance number is used only
  * to account for round-off errors.
  *
- * @version $Revision: 811685 $ $Date: 2009-09-05 13:36:48 -0400 (Sat, 05 Sep 2009) $
+ * @version $Revision: 1070725 $ $Date: 2011-02-15 02:31:12 +0100 (mar. 15 févr. 2011) $
  */
 public final class FastSineTransformerTest extends TestCase {
 
@@ -52,7 +52,7 @@ public final class FastSineTransformerTest extends TestCase {
             assertEquals(x[i], result[i], tolerance);
         }
 
-        FastFourierTransformer.scaleArray(x, Math.sqrt(x.length / 2.0));
+        FastFourierTransformer.scaleArray(x, FastMath.sqrt(x.length / 2.0));
 
         result = transformer.transform2(y);
         for (int i = 0; i < result.length; i++) {
@@ -68,19 +68,19 @@ public final class FastSineTransformerTest extends TestCase {
     /**
      * Test of transformer for the sine function.
      */
-    public void testSinFunction() throws MathException {
+    public void testSinFunction() throws Exception {
         UnivariateRealFunction f = new SinFunction();
         FastSineTransformer transformer = new FastSineTransformer();
         double min, max, result[], tolerance = 1E-12; int N = 1 << 8;
 
-        min = 0.0; max = 2.0 * Math.PI;
+        min = 0.0; max = 2.0 * FastMath.PI;
         result = transformer.transform(f, min, max, N);
         assertEquals(N >> 1, result[2], tolerance);
         for (int i = 0; i < N; i += (i == 1 ? 2 : 1)) {
             assertEquals(0.0, result[i], tolerance);
         }
 
-        min = -Math.PI; max = Math.PI;
+        min = -FastMath.PI; max = FastMath.PI;
         result = transformer.transform(f, min, max, N);
         assertEquals(-(N >> 1), result[2], tolerance);
         for (int i = 0; i < N; i += (i == 1 ? 2 : 1)) {
